@@ -1,24 +1,21 @@
 # Natural Language Toolkit: Regular Expression Chunkers
 #
-# Copyright (C) 2001-2014 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com> (minor additions)
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
-from __future__ import print_function, unicode_literals
-from __future__ import division
 
 import re
 
 from nltk.tree import Tree
 from nltk.chunk.api import ChunkParserI
-from nltk.compat import python_2_unicode_compatible, string_types, unicode_repr
 
 ##//////////////////////////////////////////////////////
 ##  ChunkString
 ##//////////////////////////////////////////////////////
 
-@python_2_unicode_compatible
+
 class ChunkString(object):
     """
     A string-based encoding of a particular chunking of a text.
@@ -56,18 +53,19 @@ class ChunkString(object):
     :cvar IN_CHINK_PATTERN: A zero-width regexp pattern string that
         will only match positions that are in chinks.
     """
-    CHUNK_TAG_CHAR = r'[^\{\}<>]'
-    CHUNK_TAG = r'(<%s+?>)' % CHUNK_TAG_CHAR
 
-    IN_CHUNK_PATTERN = r'(?=[^\{]*\})'
-    IN_CHINK_PATTERN = r'(?=[^\}]*(\{|$))'
+    CHUNK_TAG_CHAR = r"[^\{\}<>]"
+    CHUNK_TAG = r"(<%s+?>)" % CHUNK_TAG_CHAR
+
+    IN_CHUNK_PATTERN = r"(?=[^\{]*\})"
+    IN_CHINK_PATTERN = r"(?=[^\}]*(\{|$))"
 
     # These are used by _verify
-    _CHUNK = r'(\{%s+?\})+?' % CHUNK_TAG
-    _CHINK = r'(%s+?)+?' % CHUNK_TAG
-    _VALID = re.compile(r'^(\{?%s\}?)*?$' % CHUNK_TAG)
-    _BRACKETS = re.compile('[^\{\}]+')
-    _BALANCED_BRACKETS = re.compile(r'(\{\})*$')
+    _CHUNK = r"(\{%s+?\})+?" % CHUNK_TAG
+    _CHINK = r"(%s+?)+?" % CHUNK_TAG
+    _VALID = re.compile(r"^(\{?%s\}?)*?$" % CHUNK_TAG)
+    _BRACKETS = re.compile("[^\{\}]+")
+    _BALANCED_BRACKETS = re.compile(r"(\{\})*$")
 
     def __init__(self, chunk_struct, debug_level=1):
         """
@@ -93,7 +91,7 @@ class ChunkString(object):
         self._root_label = chunk_struct.label()
         self._pieces = chunk_struct[:]
         tags = [self._tag(tok) for tok in self._pieces]
-        self._str = '<' + '><'.join(tags) + '>'
+        self._str = "<" + "><".join(tags) + ">"
         self._debug = debug_level
 
     def _tag(self, tok):
@@ -102,8 +100,7 @@ class ChunkString(object):
         elif isinstance(tok, Tree):
             return tok.label()
         else:
-            raise ValueError('chunk structures must contain tagged '
-                             'tokens or trees')
+            raise ValueError("chunk structures must contain tagged " "tokens or trees")
 
     def _verify(self, s, verify_tags):
         """
@@ -123,28 +120,32 @@ class ChunkString(object):
         """
         # Check overall form
         if not ChunkString._VALID.match(s):
-            raise ValueError('Transformation generated invalid '
-                             'chunkstring:\n  %s' % s)
+            raise ValueError(
+                "Transformation generated invalid " "chunkstring:\n  %s" % s
+            )
 
         # Check that parens are balanced.  If the string is long, we
         # have to do this in pieces, to avoid a maximum recursion
         # depth limit for regular expressions.
-        brackets = ChunkString._BRACKETS.sub('', s)
+        brackets = ChunkString._BRACKETS.sub("", s)
         for i in range(1 + len(brackets) // 5000):
-            substr = brackets[i*5000:i*5000+5000]
+            substr = brackets[i * 5000 : i * 5000 + 5000]
             if not ChunkString._BALANCED_BRACKETS.match(substr):
-                raise ValueError('Transformation generated invalid '
-                                 'chunkstring:\n  %s' % s)
+                raise ValueError(
+                    "Transformation generated invalid " "chunkstring:\n  %s" % s
+                )
 
-        if verify_tags<=0: return
+        if verify_tags <= 0:
+            return
 
-        tags1 = (re.split(r'[\{\}<>]+', s))[1:-1]
+        tags1 = (re.split(r"[\{\}<>]+", s))[1:-1]
         tags2 = [self._tag(piece) for piece in self._pieces]
         if tags1 != tags2:
-            raise ValueError('Transformation generated invalid '
-                             'chunkstring: tag changed')
+            raise ValueError(
+                "Transformation generated invalid " "chunkstring: tag changed"
+            )
 
-    def to_chunkstruct(self, chunk_label='CHUNK'):
+    def to_chunkstruct(self, chunk_label="CHUNK"):
         """
         Return the chunk structure encoded by this ``ChunkString``.
 
@@ -152,17 +153,18 @@ class ChunkString(object):
         :raise ValueError: If a transformation has generated an
             invalid chunkstring.
         """
-        if self._debug > 0: self._verify(self._str, 1)
+        if self._debug > 0:
+            self._verify(self._str, 1)
 
         # Use this alternating list to create the chunkstruct.
         pieces = []
         index = 0
         piece_in_chunk = 0
-        for piece in re.split('[{}]', self._str):
+        for piece in re.split("[{}]", self._str):
 
             # Find the list of tokens contained in this piece.
-            length = piece.count('<')
-            subsequence = self._pieces[index:index+length]
+            length = piece.count("<")
+            subsequence = self._pieces[index : index + length]
 
             # Add this list of tokens to our pieces.
             if piece_in_chunk:
@@ -207,10 +209,11 @@ class ChunkString(object):
         # The substitution might have generated "empty chunks"
         # (substrings of the form "{}").  Remove them, so they don't
         # interfere with other transformations.
-        s = re.sub('\{\}', '', s)
+        s = re.sub("\{\}", "", s)
 
         # Make sure that the transformation was legal.
-        if self._debug > 1: self._verify(s, self._debug-2)
+        if self._debug > 1:
+            self._verify(s, self._debug - 2)
 
         # Commit the transformation.
         self._str = s
@@ -224,7 +227,7 @@ class ChunkString(object):
 
         :rtype: str
         """
-        return '<ChunkString: %s>' % unicode_repr(self._str)
+        return "<ChunkString: %s>" % repr(self._str)
 
     def __str__(self):
         """
@@ -236,16 +239,18 @@ class ChunkString(object):
        :rtype: str
         """
         # Add spaces to make everything line up.
-        str = re.sub(r'>(?!\})', r'> ', self._str)
-        str = re.sub(r'([^\{])<', r'\1 <', str)
-        if str[0] == '<': str = ' ' + str
+        str = re.sub(r">(?!\})", r"> ", self._str)
+        str = re.sub(r"([^\{])<", r"\1 <", str)
+        if str[0] == "<":
+            str = " " + str
         return str
 
+
 ##//////////////////////////////////////////////////////
 ##  Chunking Rules
 ##//////////////////////////////////////////////////////
 
-@python_2_unicode_compatible
+
 class RegexpChunkRule(object):
     """
     A rule specifying how to modify the chunking in a ``ChunkString``,
@@ -271,6 +276,7 @@ class RegexpChunkRule(object):
     of angle-bracket delimited tags.  Furthermore, this transformation
     may not result in nested or mismatched bracketing.
     """
+
     def __init__(self, regexp, repl, descr):
         """
         Construct a new RegexpChunkRule.
@@ -289,7 +295,7 @@ class RegexpChunkRule(object):
         :param descr: A short description of the purpose and/or effect
             of this rule.
         """
-        if isinstance(regexp, string_types):
+        if isinstance(regexp, str):
             regexp = re.compile(regexp)
         self._repl = repl
         self._descr = descr
@@ -331,8 +337,13 @@ class RegexpChunkRule(object):
 
         :rtype: str
         """
-        return ('<RegexpChunkRule: '+unicode_repr(self._regexp.pattern)+
-                '->'+unicode_repr(self._repl)+'>')
+        return (
+            "<RegexpChunkRule: "
+            + repr(self._regexp.pattern)
+            + "->"
+            + repr(self._repl)
+            + ">"
+        )
 
     @staticmethod
     def fromstring(s):
@@ -354,34 +365,33 @@ class RegexpChunkRule(object):
         <ChunkRule: '<DT>?<NN.*>+'>
         """
         # Split off the comment (but don't split on '\#')
-        m = re.match(r'(?P<rule>(\\.|[^#])*)(?P<comment>#.*)?', s)
-        rule = m.group('rule').strip()
-        comment = (m.group('comment') or '')[1:].strip()
+        m = re.match(r"(?P<rule>(\\.|[^#])*)(?P<comment>#.*)?", s)
+        rule = m.group("rule").strip()
+        comment = (m.group("comment") or "")[1:].strip()
 
         # Pattern bodies: chunk, chink, split, merge
         try:
             if not rule:
-                raise ValueError('Empty chunk pattern')
-            if rule[0] == '{' and rule[-1] == '}':
+                raise ValueError("Empty chunk pattern")
+            if rule[0] == "{" and rule[-1] == "}":
                 return ChunkRule(rule[1:-1], comment)
-            elif rule[0] == '}' and rule[-1] == '{':
+            elif rule[0] == "}" and rule[-1] == "{":
                 return ChinkRule(rule[1:-1], comment)
-            elif '}{' in rule:
-                left, right = rule.split('}{')
+            elif "}{" in rule:
+                left, right = rule.split("}{")
                 return SplitRule(left, right, comment)
-            elif '{}' in rule:
-                left, right = rule.split('{}')
+            elif "{}" in rule:
+                left, right = rule.split("{}")
                 return MergeRule(left, right, comment)
-            elif re.match('[^{}]*{[^{}]*}[^{}]*', rule):
-                left, chunk, right = re.split('[{}]', rule)
+            elif re.match("[^{}]*{[^{}]*}[^{}]*", rule):
+                left, chunk, right = re.split("[{}]", rule)
                 return ChunkRuleWithContext(left, chunk, right, comment)
             else:
-                raise ValueError('Illegal chunk pattern: %s' % rule)
+                raise ValueError("Illegal chunk pattern: %s" % rule)
         except (ValueError, re.error):
-            raise ValueError('Illegal chunk pattern: %s' % rule)
+            raise ValueError("Illegal chunk pattern: %s" % rule)
 
 
-@python_2_unicode_compatible
 class ChunkRule(RegexpChunkRule):
     """
     A rule specifying how to add chunks to a ``ChunkString``, using a
@@ -390,6 +400,7 @@ class ChunkRule(RegexpChunkRule):
     already part of a chunk, and create a new chunk containing that
     substring.
     """
+
     def __init__(self, tag_pattern, descr):
 
         """
@@ -405,10 +416,11 @@ class ChunkRule(RegexpChunkRule):
             of this rule.
         """
         self._pattern = tag_pattern
-        regexp = re.compile('(?P<chunk>%s)%s' %
-                            (tag_pattern2re_pattern(tag_pattern),
-                             ChunkString.IN_CHINK_PATTERN))
-        RegexpChunkRule.__init__(self, regexp, '{\g<chunk>}', descr)
+        regexp = re.compile(
+            "(?P<chunk>%s)%s"
+            % (tag_pattern2re_pattern(tag_pattern), ChunkString.IN_CHINK_PATTERN)
+        )
+        RegexpChunkRule.__init__(self, regexp, "{\g<chunk>}", descr)
 
     def __repr__(self):
         """
@@ -422,9 +434,9 @@ class ChunkRule(RegexpChunkRule):
 
         :rtype: str
         """
-        return '<ChunkRule: '+unicode_repr(self._pattern)+'>'
+        return "<ChunkRule: " + repr(self._pattern) + ">"
+
 
-@python_2_unicode_compatible
 class ChinkRule(RegexpChunkRule):
     """
     A rule specifying how to remove chinks to a ``ChunkString``,
@@ -433,6 +445,7 @@ class ChinkRule(RegexpChunkRule):
     tag pattern and that is contained in a chunk, and remove it
     from that chunk, thus creating two new chunks.
     """
+
     def __init__(self, tag_pattern, descr):
         """
         Construct a new ``ChinkRule``.
@@ -448,10 +461,11 @@ class ChinkRule(RegexpChunkRule):
             of this rule.
         """
         self._pattern = tag_pattern
-        regexp = re.compile('(?P<chink>%s)%s' %
-                            (tag_pattern2re_pattern(tag_pattern),
-                             ChunkString.IN_CHUNK_PATTERN))
-        RegexpChunkRule.__init__(self, regexp, '}\g<chink>{', descr)
+        regexp = re.compile(
+            "(?P<chink>%s)%s"
+            % (tag_pattern2re_pattern(tag_pattern), ChunkString.IN_CHUNK_PATTERN)
+        )
+        RegexpChunkRule.__init__(self, regexp, "}\g<chink>{", descr)
 
     def __repr__(self):
         """
@@ -465,10 +479,9 @@ class ChinkRule(RegexpChunkRule):
 
         :rtype: str
         """
-        return '<ChinkRule: '+unicode_repr(self._pattern)+'>'
+        return "<ChinkRule: " + repr(self._pattern) + ">"
 
 
-@python_2_unicode_compatible
 class UnChunkRule(RegexpChunkRule):
     """
     A rule specifying how to remove chunks to a ``ChunkString``,
@@ -476,6 +489,7 @@ class UnChunkRule(RegexpChunkRule):
     ``ChunkString``, it will find any complete chunk that matches this
     tag pattern, and un-chunk it.
     """
+
     def __init__(self, tag_pattern, descr):
         """
         Construct a new ``UnChunkRule``.
@@ -490,9 +504,8 @@ class UnChunkRule(RegexpChunkRule):
             of this rule.
         """
         self._pattern = tag_pattern
-        regexp = re.compile('\{(?P<chunk>%s)\}' %
-                            tag_pattern2re_pattern(tag_pattern))
-        RegexpChunkRule.__init__(self, regexp, '\g<chunk>', descr)
+        regexp = re.compile("\{(?P<chunk>%s)\}" % tag_pattern2re_pattern(tag_pattern))
+        RegexpChunkRule.__init__(self, regexp, "\g<chunk>", descr)
 
     def __repr__(self):
         """
@@ -506,10 +519,9 @@ class UnChunkRule(RegexpChunkRule):
 
         :rtype: str
         """
-        return '<UnChunkRule: '+unicode_repr(self._pattern)+'>'
+        return "<UnChunkRule: " + repr(self._pattern) + ">"
 
 
-@python_2_unicode_compatible
 class MergeRule(RegexpChunkRule):
     """
     A rule specifying how to merge chunks in a ``ChunkString``, using
@@ -519,6 +531,7 @@ class MergeRule(RegexpChunkRule):
     beginning matches right pattern.  It will then merge those two
     chunks into a single chunk.
     """
+
     def __init__(self, left_tag_pattern, right_tag_pattern, descr):
         """
         Construct a new ``MergeRule``.
@@ -549,10 +562,14 @@ class MergeRule(RegexpChunkRule):
 
         self._left_tag_pattern = left_tag_pattern
         self._right_tag_pattern = right_tag_pattern
-        regexp = re.compile('(?P<left>%s)}{(?=%s)' %
-                            (tag_pattern2re_pattern(left_tag_pattern),
-                             tag_pattern2re_pattern(right_tag_pattern)))
-        RegexpChunkRule.__init__(self, regexp, '\g<left>', descr)
+        regexp = re.compile(
+            "(?P<left>%s)}{(?=%s)"
+            % (
+                tag_pattern2re_pattern(left_tag_pattern),
+                tag_pattern2re_pattern(right_tag_pattern),
+            )
+        )
+        RegexpChunkRule.__init__(self, regexp, "\g<left>", descr)
 
     def __repr__(self):
         """
@@ -566,11 +583,15 @@ class MergeRule(RegexpChunkRule):
 
         :rtype: str
         """
-        return ('<MergeRule: '+unicode_repr(self._left_tag_pattern)+', '+
-                unicode_repr(self._right_tag_pattern)+'>')
+        return (
+            "<MergeRule: "
+            + repr(self._left_tag_pattern)
+            + ", "
+            + repr(self._right_tag_pattern)
+            + ">"
+        )
 
 
-@python_2_unicode_compatible
 class SplitRule(RegexpChunkRule):
     """
     A rule specifying how to split chunks in a ``ChunkString``, using
@@ -580,6 +601,7 @@ class SplitRule(RegexpChunkRule):
     then split the chunk into two new chunks, at the point between the
     two pattern matches.
     """
+
     def __init__(self, left_tag_pattern, right_tag_pattern, descr):
         """
         Construct a new ``SplitRule``.
@@ -609,10 +631,14 @@ class SplitRule(RegexpChunkRule):
 
         self._left_tag_pattern = left_tag_pattern
         self._right_tag_pattern = right_tag_pattern
-        regexp = re.compile('(?P<left>%s)(?=%s)' %
-                            (tag_pattern2re_pattern(left_tag_pattern),
-                             tag_pattern2re_pattern(right_tag_pattern)))
-        RegexpChunkRule.__init__(self, regexp, r'\g<left>}{', descr)
+        regexp = re.compile(
+            "(?P<left>%s)(?=%s)"
+            % (
+                tag_pattern2re_pattern(left_tag_pattern),
+                tag_pattern2re_pattern(right_tag_pattern),
+            )
+        )
+        RegexpChunkRule.__init__(self, regexp, r"\g<left>}{", descr)
 
     def __repr__(self):
         """
@@ -626,11 +652,15 @@ class SplitRule(RegexpChunkRule):
 
        :rtype: str
         """
-        return ('<SplitRule: '+unicode_repr(self._left_tag_pattern)+', '+
-                unicode_repr(self._right_tag_pattern)+'>')
+        return (
+            "<SplitRule: "
+            + repr(self._left_tag_pattern)
+            + ", "
+            + repr(self._right_tag_pattern)
+            + ">"
+        )
 
 
-@python_2_unicode_compatible
 class ExpandLeftRule(RegexpChunkRule):
     """
     A rule specifying how to expand chunks in a ``ChunkString`` to the left,
@@ -640,6 +670,7 @@ class ExpandLeftRule(RegexpChunkRule):
     end matches left pattern.  It will then expand the chunk to incorporate
     the new material on the left.
     """
+
     def __init__(self, left_tag_pattern, right_tag_pattern, descr):
         """
         Construct a new ``ExpandRightRule``.
@@ -670,10 +701,14 @@ class ExpandLeftRule(RegexpChunkRule):
 
         self._left_tag_pattern = left_tag_pattern
         self._right_tag_pattern = right_tag_pattern
-        regexp = re.compile('(?P<left>%s)\{(?P<right>%s)' %
-                            (tag_pattern2re_pattern(left_tag_pattern),
-                             tag_pattern2re_pattern(right_tag_pattern)))
-        RegexpChunkRule.__init__(self, regexp, '{\g<left>\g<right>', descr)
+        regexp = re.compile(
+            "(?P<left>%s)\{(?P<right>%s)"
+            % (
+                tag_pattern2re_pattern(left_tag_pattern),
+                tag_pattern2re_pattern(right_tag_pattern),
+            )
+        )
+        RegexpChunkRule.__init__(self, regexp, "{\g<left>\g<right>", descr)
 
     def __repr__(self):
         """
@@ -687,11 +722,15 @@ class ExpandLeftRule(RegexpChunkRule):
 
         :rtype: str
         """
-        return ('<ExpandLeftRule: '+unicode_repr(self._left_tag_pattern)+', '+
-                unicode_repr(self._right_tag_pattern)+'>')
+        return (
+            "<ExpandLeftRule: "
+            + repr(self._left_tag_pattern)
+            + ", "
+            + repr(self._right_tag_pattern)
+            + ">"
+        )
 
 
-@python_2_unicode_compatible
 class ExpandRightRule(RegexpChunkRule):
     """
     A rule specifying how to expand chunks in a ``ChunkString`` to the
@@ -701,6 +740,7 @@ class ExpandRightRule(RegexpChunkRule):
     a chink whose beginning matches right pattern.  It will then
     expand the chunk to incorporate the new material on the right.
     """
+
     def __init__(self, left_tag_pattern, right_tag_pattern, descr):
         """
         Construct a new ``ExpandRightRule``.
@@ -731,10 +771,14 @@ class ExpandRightRule(RegexpChunkRule):
 
         self._left_tag_pattern = left_tag_pattern
         self._right_tag_pattern = right_tag_pattern
-        regexp = re.compile('(?P<left>%s)\}(?P<right>%s)' %
-                            (tag_pattern2re_pattern(left_tag_pattern),
-                             tag_pattern2re_pattern(right_tag_pattern)))
-        RegexpChunkRule.__init__(self, regexp, '\g<left>\g<right>}', descr)
+        regexp = re.compile(
+            "(?P<left>%s)\}(?P<right>%s)"
+            % (
+                tag_pattern2re_pattern(left_tag_pattern),
+                tag_pattern2re_pattern(right_tag_pattern),
+            )
+        )
+        RegexpChunkRule.__init__(self, regexp, "\g<left>\g<right>}", descr)
 
     def __repr__(self):
         """
@@ -748,11 +792,15 @@ class ExpandRightRule(RegexpChunkRule):
 
         :rtype: str
         """
-        return ('<ExpandRightRule: '+unicode_repr(self._left_tag_pattern)+', '+
-                unicode_repr(self._right_tag_pattern)+'>')
+        return (
+            "<ExpandRightRule: "
+            + repr(self._left_tag_pattern)
+            + ", "
+            + repr(self._right_tag_pattern)
+            + ">"
+        )
 
 
-@python_2_unicode_compatible
 class ChunkRuleWithContext(RegexpChunkRule):
     """
     A rule specifying how to add chunks to a ``ChunkString``, using
@@ -768,8 +816,14 @@ class ChunkRuleWithContext(RegexpChunkRule):
     rule matches; therefore, if you need to find overlapping matches,
     you will need to apply your rule more than once.
     """
-    def __init__(self, left_context_tag_pattern, chunk_tag_pattern,
-                 right_context_tag_pattern, descr):
+
+    def __init__(
+        self,
+        left_context_tag_pattern,
+        chunk_tag_pattern,
+        right_context_tag_pattern,
+        descr,
+    ):
         """
         Construct a new ``ChunkRuleWithContext``.
 
@@ -798,12 +852,16 @@ class ChunkRuleWithContext(RegexpChunkRule):
         self._left_context_tag_pattern = left_context_tag_pattern
         self._chunk_tag_pattern = chunk_tag_pattern
         self._right_context_tag_pattern = right_context_tag_pattern
-        regexp = re.compile('(?P<left>%s)(?P<chunk>%s)(?P<right>%s)%s' %
-                            (tag_pattern2re_pattern(left_context_tag_pattern),
-                             tag_pattern2re_pattern(chunk_tag_pattern),
-                             tag_pattern2re_pattern(right_context_tag_pattern),
-                             ChunkString.IN_CHINK_PATTERN))
-        replacement = r'\g<left>{\g<chunk>}\g<right>'
+        regexp = re.compile(
+            "(?P<left>%s)(?P<chunk>%s)(?P<right>%s)%s"
+            % (
+                tag_pattern2re_pattern(left_context_tag_pattern),
+                tag_pattern2re_pattern(chunk_tag_pattern),
+                tag_pattern2re_pattern(right_context_tag_pattern),
+                ChunkString.IN_CHINK_PATTERN,
+            )
+        )
+        replacement = r"\g<left>{\g<chunk>}\g<right>"
         RegexpChunkRule.__init__(self, regexp, replacement, descr)
 
     def __repr__(self):
@@ -818,9 +876,12 @@ class ChunkRuleWithContext(RegexpChunkRule):
 
         :rtype: str
         """
-        return '<ChunkRuleWithContext:  %r, %r, %r>' % (
-            self._left_context_tag_pattern, self._chunk_tag_pattern,
-            self._right_context_tag_pattern)
+        return "<ChunkRuleWithContext:  %r, %r, %r>" % (
+            self._left_context_tag_pattern,
+            self._chunk_tag_pattern,
+            self._right_context_tag_pattern,
+        )
+
 
 ##//////////////////////////////////////////////////////
 ##  Tag Pattern Format Conversion
@@ -828,9 +889,10 @@ class ChunkRuleWithContext(RegexpChunkRule):
 
 # this should probably be made more strict than it is -- e.g., it
 # currently accepts 'foo'.
-CHUNK_TAG_PATTERN = re.compile(r'^((%s|<%s>)*)$' %
-                                ('[^\{\}<>]+',
-                                 '[^\{\}<>]+'))
+CHUNK_TAG_PATTERN = re.compile(
+    r"^((%s|<%s>)*)$" % ("([^\{\}<>]|\{\d+,?\}|\{\d*,\d+\})+", "[^\{\}<>]+")
+)
+
 
 def tag_pattern2re_pattern(tag_pattern):
     """
@@ -869,13 +931,13 @@ def tag_pattern2re_pattern(tag_pattern):
         ``tag_pattern``.
     """
     # Clean up the regular expression
-    tag_pattern = re.sub(r'\s', '', tag_pattern)
-    tag_pattern = re.sub(r'<', '(<(', tag_pattern)
-    tag_pattern = re.sub(r'>', ')>)', tag_pattern)
+    tag_pattern = re.sub(r"\s", "", tag_pattern)
+    tag_pattern = re.sub(r"<", "(<(", tag_pattern)
+    tag_pattern = re.sub(r">", ")>)", tag_pattern)
 
     # Check the regular expression
     if not CHUNK_TAG_PATTERN.match(tag_pattern):
-        raise ValueError('Bad tag pattern: %r' % tag_pattern)
+        raise ValueError("Bad tag pattern: %r" % tag_pattern)
 
     # Replace "." with CHUNK_TAG_CHAR.
     # We have to do this after, since it adds {}[]<>s, which would
@@ -886,10 +948,11 @@ def tag_pattern2re_pattern(tag_pattern):
     def reverse_str(str):
         lst = list(str)
         lst.reverse()
-        return ''.join(lst)
+        return "".join(lst)
+
     tc_rev = reverse_str(ChunkString.CHUNK_TAG_CHAR)
     reversed = reverse_str(tag_pattern)
-    reversed = re.sub(r'\.(?!\\(\\\\)*($|[^\\]))', tc_rev, reversed)
+    reversed = re.sub(r"\.(?!\\(\\\\)*($|[^\\]))", tc_rev, reversed)
     tag_pattern = reverse_str(reversed)
 
     return tag_pattern
@@ -899,7 +962,7 @@ def tag_pattern2re_pattern(tag_pattern):
 ##  RegexpChunkParser
 ##//////////////////////////////////////////////////////
 
-@python_2_unicode_compatible
+
 class RegexpChunkParser(ChunkParserI):
     """
     A regular expression based chunk parser.  ``RegexpChunkParser`` uses a
@@ -921,7 +984,8 @@ class RegexpChunkParser(ChunkParserI):
     :ivar _trace: The default level of tracing.
 
     """
-    def __init__(self, rules, chunk_label='NP', root_label='S', trace=0):
+
+    def __init__(self, rules, chunk_label="NP", root_label="S", trace=0):
         """
         Construct a new ``RegexpChunkParser``.
 
@@ -960,14 +1024,14 @@ class RegexpChunkParser(ChunkParserI):
         :param verbose: Whether output should be verbose.
         :rtype: None
         """
-        print('# Input:')
+        print("# Input:")
         print(chunkstr)
         for rule in self._rules:
             rule.apply(chunkstr)
             if verbose:
-                print('#', rule.descr()+' ('+unicode_repr(rule)+'):')
+                print("#", rule.descr() + " (" + repr(rule) + "):")
             else:
-                print('#', rule.descr()+':')
+                print("#", rule.descr() + ":")
             print(chunkstr)
 
     def _notrace_apply(self, chunkstr):
@@ -1003,7 +1067,7 @@ class RegexpChunkParser(ChunkParserI):
             used to define this ``RegexpChunkParser``.
         """
         if len(chunk_struct) == 0:
-            print('Warning: parsing empty text')
+            print("Warning: parsing empty text")
             return Tree(self._root_label, [])
 
         try:
@@ -1012,13 +1076,14 @@ class RegexpChunkParser(ChunkParserI):
             chunk_struct = Tree(self._root_label, chunk_struct)
 
         # Use the default trace value?
-        if trace is None: trace = self._trace
+        if trace is None:
+            trace = self._trace
 
         chunkstr = ChunkString(chunk_struct)
 
         # Apply the sequence of rules to the chunkstring.
         if trace:
-            verbose = (trace>1)
+            verbose = trace > 1
             self._trace_apply(chunkstr, verbose)
         else:
             self._notrace_apply(chunkstr)
@@ -1051,18 +1116,19 @@ class RegexpChunkParser(ChunkParserI):
         for rule in self._rules:
             margin = max(margin, len(rule.descr()))
         if margin < 35:
-            format = "    %" + repr(-(margin+3)) + "s%s\n"
+            format = "    %" + repr(-(margin + 3)) + "s%s\n"
         else:
             format = "    %s\n      %s\n"
         for rule in self._rules:
-            s += format % (rule.descr(), unicode_repr(rule))
+            s += format % (rule.descr(), repr(rule))
         return s[:-1]
 
+
 ##//////////////////////////////////////////////////////
 ##  Chunk Grammar
 ##//////////////////////////////////////////////////////
 
-@python_2_unicode_compatible
+
 class RegexpParser(ChunkParserI):
     """
     A grammar based chunk parser.  ``chunk.RegexpParser`` uses a set of
@@ -1104,7 +1170,8 @@ class RegexpParser(ChunkParserI):
     :ivar _stages: The list of parsing stages corresponding to the grammar
 
     """
-    def __init__(self, grammar, root_label='S', loop=1, trace=0):
+
+    def __init__(self, grammar, root_label="S", loop=1, trace=0):
         """
         Create a new chunk parser, from the given start state
         and set of chunk patterns.
@@ -1126,14 +1193,17 @@ class RegexpParser(ChunkParserI):
         self._grammar = grammar
         self._loop = loop
 
-        if isinstance(grammar, string_types):
+        if isinstance(grammar, str):
             self._read_grammar(grammar, root_label, trace)
         else:
             # Make sur the grammar looks like it has the right type:
-            type_err = ('Expected string or list of RegexpChunkParsers '
-                        'for the grammar.')
-            try: grammar = list(grammar)
-            except: raise TypeError(type_err)
+            type_err = (
+                "Expected string or list of RegexpChunkParsers " "for the grammar."
+            )
+            try:
+                grammar = list(grammar)
+            except:
+                raise TypeError(type_err)
             for elt in grammar:
                 if not isinstance(elt, RegexpChunkParser):
                     raise TypeError(type_err)
@@ -1146,21 +1216,22 @@ class RegexpParser(ChunkParserI):
         """
         rules = []
         lhs = None
-        for line in grammar.split('\n'):
+        for line in grammar.split("\n"):
             line = line.strip()
 
             # New stage begins if there's an unescaped ':'
-            m = re.match('(?P<nonterminal>(\\.|[^:])*)(:(?P<rule>.*))', line)
+            m = re.match("(?P<nonterminal>(\\.|[^:])*)(:(?P<rule>.*))", line)
             if m:
                 # Record the stage that we just completed.
                 self._add_stage(rules, lhs, root_label, trace)
                 # Start a new stage.
-                lhs = m.group('nonterminal').strip()
+                lhs = m.group("nonterminal").strip()
                 rules = []
-                line = m.group('rule').strip()
+                line = m.group("rule").strip()
 
             # Skip blank & comment-only lines
-            if line=='' or line.startswith('#'): continue
+            if line == "" or line.startswith("#"):
+                continue
 
             # Add the rule
             rules.append(RegexpChunkRule.fromstring(line))
@@ -1174,9 +1245,10 @@ class RegexpParser(ChunkParserI):
         """
         if rules != []:
             if not lhs:
-                raise ValueError('Expected stage marker (eg NP:)')
-            parser = RegexpChunkParser(rules, chunk_label=lhs,
-                                       root_label=root_label, trace=trace)
+                raise ValueError("Expected stage marker (eg NP:)")
+            parser = RegexpChunkParser(
+                rules, chunk_label=lhs, root_label=root_label, trace=trace
+            )
             self._stages.append(parser)
 
     def parse(self, chunk_struct, trace=None):
@@ -1196,7 +1268,8 @@ class RegexpParser(ChunkParserI):
         :return: the chunked output.
         :rtype: Tree
         """
-        if trace is None: trace = self._trace
+        if trace is None:
+            trace = self._trace
         for i in range(self._loop):
             for parser in self._stages:
                 chunk_struct = parser.parse(chunk_struct, trace=trace)
@@ -1221,10 +1294,12 @@ class RegexpParser(ChunkParserI):
             s += "%s\n" % parser
         return s[:-1]
 
+
 ##//////////////////////////////////////////////////////
 ##  Demonstration code
 ##//////////////////////////////////////////////////////
 
+
 def demo_eval(chunkparser, text):
     """
     Demonstration code for evaluating a chunk parser, using a
@@ -1248,45 +1323,46 @@ def demo_eval(chunkparser, text):
     # Evaluate our chunk parser.
     chunkscore = chunk.ChunkScore()
 
-    for sentence in text.split('\n'):
+    for sentence in text.split("\n"):
         print(sentence)
         sentence = sentence.strip()
-        if not sentence: continue
+        if not sentence:
+            continue
         gold = chunk.tagstr2tree(sentence)
         tokens = gold.leaves()
-        test = chunkparser.parse(Tree('S', tokens), trace=1)
+        test = chunkparser.parse(Tree("S", tokens), trace=1)
         chunkscore.score(gold, test)
         print()
 
-    print('/'+('='*75)+'\\')
-    print('Scoring', chunkparser)
-    print(('-'*77))
-    print('Precision: %5.1f%%' % (chunkscore.precision()*100), ' '*4, end=' ')
-    print('Recall: %5.1f%%' % (chunkscore.recall()*100), ' '*6, end=' ')
-    print('F-Measure: %5.1f%%' % (chunkscore.f_measure()*100))
-
+    print("/" + ("=" * 75) + "\\")
+    print("Scoring", chunkparser)
+    print(("-" * 77))
+    print("Precision: %5.1f%%" % (chunkscore.precision() * 100), " " * 4, end=" ")
+    print("Recall: %5.1f%%" % (chunkscore.recall() * 100), " " * 6, end=" ")
+    print("F-Measure: %5.1f%%" % (chunkscore.f_measure() * 100))
 
     # Missed chunks.
     if chunkscore.missed():
-        print('Missed:')
+        print("Missed:")
         missed = chunkscore.missed()
         for chunk in missed[:10]:
-            print('  ', ' '.join(map(str,chunk)))
+            print("  ", " ".join(map(str, chunk)))
         if len(chunkscore.missed()) > 10:
-            print('  ...')
+            print("  ...")
 
     # Incorrect chunks.
     if chunkscore.incorrect():
-        print('Incorrect:')
+        print("Incorrect:")
         incorrect = chunkscore.incorrect()
         for chunk in incorrect[:10]:
-            print('  ', ' '.join(map(str,chunk)))
+            print("  ", " ".join(map(str, chunk)))
         if len(chunkscore.incorrect()) > 10:
-            print('  ...')
+            print("  ...")
 
-    print('\\'+('='*75)+'/')
+    print("\\" + ("=" * 75) + "/")
     print()
 
+
 def demo():
     """
     A demonstration for the ``RegexpChunkParser`` class.  A single text is
@@ -1302,10 +1378,10 @@ def demo():
     [ John/NNP ] thinks/VBZ [ Mary/NN ] saw/VBD [ the/DT cat/NN ] sit/VB on/IN [ the/DT mat/NN ]./.
     """
 
-    print('*'*75)
-    print('Evaluation text:')
+    print("*" * 75)
+    print("Evaluation text:")
     print(text)
-    print('*'*75)
+    print("*" * 75)
     print()
 
     grammar = r"""
@@ -1342,7 +1418,7 @@ def demo():
     cp = chunk.RegexpParser(grammar)
     demo_eval(cp, text)
 
-# Evaluation
+    # Evaluation
 
     from nltk.corpus import conll2000
 
@@ -1350,8 +1426,7 @@ def demo():
     print("Demonstration of empty grammar:")
 
     cp = chunk.RegexpParser("")
-    print(chunk.accuracy(cp, conll2000.chunked_sents('test.txt',
-                                                     chunk_types=('NP',))))
+    print(chunk.accuracy(cp, conll2000.chunked_sents("test.txt", chunk_types=("NP",))))
 
     print()
     print("Demonstration of accuracy evaluation using CoNLL tags:")
@@ -1363,7 +1438,7 @@ def demo():
       <DT|JJ>{}<NN.*>     # merge det/adj with nouns
     """
     cp = chunk.RegexpParser(grammar)
-    print(chunk.accuracy(cp, conll2000.chunked_sents('test.txt')[:5]))
+    print(chunk.accuracy(cp, conll2000.chunked_sents("test.txt")[:5]))
 
     print()
     print("Demonstration of tagged token input")
@@ -1376,9 +1451,21 @@ def demo():
     VP: {<VB.*><NP|PP>*}    # VP = verb words + NPs and PPs
     """
     cp = chunk.RegexpParser(grammar)
-    print(cp.parse([("the","DT"), ("little","JJ"), ("cat", "NN"),
-                    ("sat", "VBD"), ("on", "IN"), ("the", "DT"),
-                    ("mat", "NN"), (".", ".")]))
+    print(
+        cp.parse(
+            [
+                ("the", "DT"),
+                ("little", "JJ"),
+                ("cat", "NN"),
+                ("sat", "VBD"),
+                ("on", "IN"),
+                ("the", "DT"),
+                ("mat", "NN"),
+                (".", "."),
+            ]
+        )
+    )
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     demo()
