@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Interface to Megam Classifier
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -22,13 +22,8 @@ for details.
 
 .. _megam: http://www.umiacs.umd.edu/~hal/megam/index.html
 """
-from __future__ import print_function
-
 import subprocess
 
-from six import string_types
-
-from nltk import compat
 from nltk.internals import find_binary
 
 try:
@@ -55,11 +50,11 @@ def config_megam(bin=None):
     """
     global _megam_bin
     _megam_bin = find_binary(
-        'megam',
+        "megam",
         bin,
-        env_vars=['MEGAM'],
-        binary_names=['megam.opt', 'megam', 'megam_686', 'megam_i686.opt'],
-        url='http://www.umiacs.umd.edu/~hal/megam/index.html',
+        env_vars=["MEGAM"],
+        binary_names=["megam.opt", "megam", "megam_686", "megam_i686.opt"],
+        url="http://www.umiacs.umd.edu/~hal/megam/index.html",
     )
 
 
@@ -105,12 +100,12 @@ def write_megam_file(train_toks, encoding, stream, bernoulli=True, explicit=True
     # Write the file, which contains one line per instance.
     for featureset, label in train_toks:
         # First, the instance number (or, in the weighted multiclass case, the cost of each label).
-        if hasattr(encoding, 'cost'):
+        if hasattr(encoding, "cost"):
             stream.write(
-                ':'.join(str(encoding.cost(featureset, label, l)) for l in labels)
+                ":".join(str(encoding.cost(featureset, label, l)) for l in labels)
             )
         else:
-            stream.write('%d' % labelnum[label])
+            stream.write("%d" % labelnum[label])
 
         # For implicit file formats, just list the features that fire
         # for this instance's actual label.
@@ -121,11 +116,11 @@ def write_megam_file(train_toks, encoding, stream, bernoulli=True, explicit=True
         # any of the possible labels.
         else:
             for l in labels:
-                stream.write(' #')
+                stream.write(" #")
                 _write_megam_features(encoding.encode(featureset, l), stream, bernoulli)
 
         # End of the instance.
-        stream.write('\n')
+        stream.write("\n")
 
 
 def parse_megam_weights(s, features_count, explicit=True):
@@ -135,10 +130,10 @@ def parse_megam_weights(s, features_count, explicit=True):
     vector.  This function does not currently handle bias features.
     """
     if numpy is None:
-        raise ValueError('This function requires that numpy be installed')
-    assert explicit, 'non-explicit not supported yet'
-    lines = s.strip().split('\n')
-    weights = numpy.zeros(features_count, 'd')
+        raise ValueError("This function requires that numpy be installed")
+    assert explicit, "non-explicit not supported yet"
+    lines = s.strip().split("\n")
+    weights = numpy.zeros(features_count, "d")
     for line in lines:
         if line.strip():
             fid, weight = line.split()
@@ -149,26 +144,26 @@ def parse_megam_weights(s, features_count, explicit=True):
 def _write_megam_features(vector, stream, bernoulli):
     if not vector:
         raise ValueError(
-            'MEGAM classifier requires the use of an ' 'always-on feature.'
+            "MEGAM classifier requires the use of an " "always-on feature."
         )
     for (fid, fval) in vector:
         if bernoulli:
             if fval == 1:
-                stream.write(' %s' % fid)
+                stream.write(" %s" % fid)
             elif fval != 0:
                 raise ValueError(
-                    'If bernoulli=True, then all' 'features must be binary.'
+                    "If bernoulli=True, then all" "features must be binary."
                 )
         else:
-            stream.write(' %s %s' % (fid, fval))
+            stream.write(" %s %s" % (fid, fval))
 
 
 def call_megam(args):
     """
     Call the ``megam`` binary with the given arguments.
     """
-    if isinstance(args, string_types):
-        raise TypeError('args should be a list of strings')
+    if isinstance(args, str):
+        raise TypeError("args should be a list of strings")
     if _megam_bin is None:
         config_megam()
 
@@ -181,9 +176,9 @@ def call_megam(args):
     if p.returncode != 0:
         print()
         print(stderr)
-        raise OSError('megam command failed!')
+        raise OSError("megam command failed!")
 
-    if isinstance(stdout, string_types):
+    if isinstance(stdout, str):
         return stdout
     else:
-        return stdout.decode('utf-8')
+        return stdout.decode("utf-8")
