@@ -8,7 +8,7 @@ scikit-learn (http://scikit-learn.org) is a machine learning library for
 Python. It supports many classification algorithms, including SVMs,
 Naive Bayes, logistic regression (MaxEnt) and decision trees.
 
-This package implement a wrapper around scikit-learn classifiers. To use this
+This package implements a wrapper around scikit-learn classifiers. To use this
 wrapper, construct a scikit-learn estimator object, then use that to construct
 a SklearnClassifier. E.g., to wrap a linear SVM with default settings:
 
@@ -30,12 +30,9 @@ best 1000 features:
 ...                      ('nb', MultinomialNB())])
 >>> classif = SklearnClassifier(pipeline)
 """
-from __future__ import print_function, unicode_literals
 
 from nltk.classify.api import ClassifierI
 from nltk.probability import DictionaryProbDist
-from nltk import compat
-from warnings import warn
 
 try:
     from sklearn.feature_extraction import DictVectorizer
@@ -43,10 +40,9 @@ try:
 except ImportError:
     pass
 
-__all__ = ['SklearnClassifier']
+__all__ = ["SklearnClassifier"]
 
 
-@compat.python_2_unicode_compatible
 class SklearnClassifier(ClassifierI):
     """Wrapper for scikit-learn classifiers."""
 
@@ -112,7 +108,7 @@ class SklearnClassifier(ClassifierI):
             numbers, booleans or strings.
         """
 
-        X, y = list(compat.izip(*labeled_featuresets))
+        X, y = list(zip(*labeled_featuresets))
         X = self._vectorizer.fit_transform(X)
         y = self._encoder.fit_transform(y)
         self._clf.fit(X, y)
@@ -121,13 +117,13 @@ class SklearnClassifier(ClassifierI):
 
     def _make_probdist(self, y_proba):
         classes = self._encoder.classes_
-        return DictionaryProbDist(dict((classes[i], p)
-                                       for i, p in enumerate(y_proba)))
+        return DictionaryProbDist(dict((classes[i], p) for i, p in enumerate(y_proba)))
 
 
 # skip doctests if scikit-learn is not installed
 def setup_module(module):
     from nose import SkipTest
+
     try:
         import sklearn
     except ImportError:
@@ -142,11 +138,15 @@ if __name__ == "__main__":
     # Bernoulli Naive Bayes is designed for binary classification. We set the
     # binarize option to False since we know we're passing boolean features.
     print("scikit-learn Naive Bayes:")
-    names_demo(SklearnClassifier(BernoulliNB(binarize=False)).train,
-               features=names_demo_features)
+    names_demo(
+        SklearnClassifier(BernoulliNB(binarize=False)).train,
+        features=names_demo_features,
+    )
 
     # The C parameter on logistic regression (MaxEnt) controls regularization.
     # The higher it's set, the less regularized the classifier is.
     print("\n\nscikit-learn logistic regression:")
-    names_demo(SklearnClassifier(LogisticRegression(C=1000)).train,
-               features=names_demo_features)
+    names_demo(
+        SklearnClassifier(LogisticRegression(C=1000)).train,
+        features=names_demo_features,
+    )
