@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Interface to Weka Classsifiers
 #
-# Copyright (C) 2001-2015 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -8,27 +8,30 @@
 """
 Classifiers that make use of the external 'Weka' package.
 """
-from __future__ import print_function
+
 import time
 import tempfile
 import os
 import subprocess
 import re
 import zipfile
-
 from sys import stdin
-from nltk import compat
+
 from nltk.probability import DictionaryProbDist
 from nltk.internals import java, config_java
 
 from nltk.classify.api import ClassifierI
 
 _weka_classpath = None
-_weka_search = ['.',
-                '/usr/share/weka',
-                '/usr/local/share/weka',
-                '/usr/lib/weka',
-                '/usr/local/lib/weka',]
+_weka_search = [
+    ".",
+    "/usr/share/weka",
+    "/usr/local/share/weka",
+    "/usr/lib/weka",
+    "/usr/local/lib/weka",
+]
+
+
 def config_weka(classpath=None):
     global _weka_classpath
 
@@ -40,51 +43,56 @@ def config_weka(classpath=None):
 
     if _weka_classpath is None:
         searchpath = _weka_search
-        if 'WEKAHOME' in os.environ:
-            searchpath.insert(0, os.environ['WEKAHOME'])
+        if "WEKAHOME" in os.environ:
+            searchpath.insert(0, os.environ["WEKAHOME"])
 
         for path in searchpath:
-            if os.path.exists(os.path.join(path, 'weka.jar')):
-                _weka_classpath = os.path.join(path, 'weka.jar')
+            if os.path.exists(os.path.join(path, "weka.jar")):
+                _weka_classpath = os.path.join(path, "weka.jar")
                 version = _check_weka_version(_weka_classpath)
                 if version:
-                    print(('[Found Weka: %s (version %s)]' %
-                           (_weka_classpath, version)))
+                    print(
+                        ("[Found Weka: %s (version %s)]" % (_weka_classpath, version))
+                    )
                 else:
-                    print('[Found Weka: %s]' % _weka_classpath)
+                    print("[Found Weka: %s]" % _weka_classpath)
                 _check_weka_version(_weka_classpath)
 
     if _weka_classpath is None:
-        raise LookupError('Unable to find weka.jar!  Use config_weka() '
-                          'or set the WEKAHOME environment variable. '
-                          'For more information about Weka, please see '
-                          'http://www.cs.waikato.ac.nz/ml/weka/')
+        raise LookupError(
+            "Unable to find weka.jar!  Use config_weka() "
+            "or set the WEKAHOME environment variable. "
+            "For more information about Weka, please see "
+            "http://www.cs.waikato.ac.nz/ml/weka/"
+        )
+
 
 def _check_weka_version(jar):
     try:
         zf = zipfile.ZipFile(jar)
-    except SystemExit as KeyboardInterrupt:
+    except (SystemExit, KeyboardInterrupt):
         raise
     except:
         return None
     try:
         try:
-            return zf.read('weka/core/version.txt')
+            return zf.read("weka/core/version.txt")
         except KeyError:
             return None
     finally:
         zf.close()
 
+
 class WekaClassifier(ClassifierI):
     def __init__(self, formatter, model_filename):
         self._formatter = formatter
         self._model = model_filename
 
     def prob_classify_many(self, featuresets):
-        return self._classify_many(featuresets, ['-p', '0', '-distribution'])
+        return self._classify_many(featuresets, ["-p", "0", "-distribution"])
 
     def classify_many(self, featuresets):
-        return self._classify_many(featuresets, ['-p', '0'])
+        return self._classify_many(featuresets, ["-p", "0"])
 
     def _classify_many(self, featuresets, options):
         # Make sure we can find java & weka.
@@ -93,28 +101,37 @@ class WekaClassifier(ClassifierI):
         temp_dir = tempfile.mkdtemp()
         try:
             # Write the test data file.
-            test_filename = os.path.join(temp_dir, 'test.arff')
+            test_filename = os.path.join(temp_dir, "test.arff")
             self._formatter.write(test_filename, featuresets)
 
             # Call weka to classify the data.
-            cmd = ['weka.classifiers.bayes.NaiveBayes',
-                   '-l', self._model, '-T', test_filename] + options
-            (stdout, stderr) = java(cmd, classpath=_weka_classpath,
-                                    stdout=subprocess.PIPE,
-                                    stderr=subprocess.PIPE)
+            cmd = [
+                "weka.classifiers.bayes.NaiveBayes",
+                "-l",
+                self._model,
+                "-T",
+                test_filename,
+            ] + options
+            (stdout, stderr) = java(
+                cmd,
+                classpath=_weka_classpath,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+            )
 
             # Check if something went wrong:
             if stderr and not stdout:
-                if 'Illegal options: -distribution' in stderr:
-                    raise ValueError('The installed version of weka does '
-                                     'not support probability distribution '
-                                     'output.')
+                if "Illegal options: -distribution" in stderr:
+                    raise ValueError(
+                        "The installed version of weka does "
+                        "not support probability distribution "
+                        "output."
+                    )
                 else:
-                    raise ValueError('Weka failed to generate output:\n%s'
-                                     % stderr)
+                    raise ValueError("Weka failed to generate output:\n%s" % stderr)
 
             # Parse weka's output.
-            return self.parse_weka_output(stdout.decode(stdin.encoding).split('\n'))
+            return self.parse_weka_output(stdout.decode(stdin.encoding).split("\n"))
 
         finally:
             for f in os.listdir(temp_dir):
@@ -122,37 +139,44 @@ class WekaClassifier(ClassifierI):
             os.rmdir(temp_dir)
 
     def parse_weka_distribution(self, s):
-        probs = [float(v) for v in re.split('[*,]+', s) if v.strip()]
+        probs = [float(v) for v in re.split("[*,]+", s) if v.strip()]
         probs = dict(zip(self._formatter.labels(), probs))
         return DictionaryProbDist(probs)
 
     def parse_weka_output(self, lines):
         # Strip unwanted text from stdout
-        for i,line in enumerate(lines):
+        for i, line in enumerate(lines):
             if line.strip().startswith("inst#"):
                 lines = lines[i:]
                 break
 
-        if lines[0].split() == ['inst#', 'actual', 'predicted',
-                                'error', 'prediction']:
-            return [line.split()[2].split(':')[1]
-                    for line in lines[1:] if line.strip()]
-        elif lines[0].split() == ['inst#', 'actual', 'predicted',
-                                  'error', 'distribution']:
-            return [self.parse_weka_distribution(line.split()[-1])
-                    for line in lines[1:] if line.strip()]
+        if lines[0].split() == ["inst#", "actual", "predicted", "error", "prediction"]:
+            return [line.split()[2].split(":")[1] for line in lines[1:] if line.strip()]
+        elif lines[0].split() == [
+            "inst#",
+            "actual",
+            "predicted",
+            "error",
+            "distribution",
+        ]:
+            return [
+                self.parse_weka_distribution(line.split()[-1])
+                for line in lines[1:]
+                if line.strip()
+            ]
 
         # is this safe:?
-        elif re.match(r'^0 \w+ [01]\.[0-9]* \?\s*$', lines[0]):
+        elif re.match(r"^0 \w+ [01]\.[0-9]* \?\s*$", lines[0]):
             return [line.split()[1] for line in lines if line.strip()]
 
         else:
             for line in lines[:10]:
                 print(line)
-            raise ValueError('Unhandled output format -- your version '
-                             'of weka may not be supported.\n'
-                             '  Header: %s' % lines[0])
-
+            raise ValueError(
+                "Unhandled output format -- your version "
+                "of weka may not be supported.\n"
+                "  Header: %s" % lines[0]
+            )
 
     # [xx] full list of classifiers (some may be abstract?):
     # ADTree, AODE, BayesNet, ComplementNaiveBayes, ConjunctiveRule,
@@ -168,16 +192,23 @@ class WekaClassifier(ClassifierI):
     # VotedPerceptron, Winnow, ZeroR
 
     _CLASSIFIER_CLASS = {
-        'naivebayes': 'weka.classifiers.bayes.NaiveBayes',
-        'C4.5': 'weka.classifiers.trees.J48',
-        'log_regression': 'weka.classifiers.functions.Logistic',
-        'svm': 'weka.classifiers.functions.SMO',
-        'kstar': 'weka.classifiers.lazy.KStar',
-        'ripper': 'weka.classifiers.rules.JRip',
-        }
+        "naivebayes": "weka.classifiers.bayes.NaiveBayes",
+        "C4.5": "weka.classifiers.trees.J48",
+        "log_regression": "weka.classifiers.functions.Logistic",
+        "svm": "weka.classifiers.functions.SMO",
+        "kstar": "weka.classifiers.lazy.KStar",
+        "ripper": "weka.classifiers.rules.JRip",
+    }
+
     @classmethod
-    def train(cls, model_filename, featuresets,
-              classifier='naivebayes', options=[], quiet=True):
+    def train(
+        cls,
+        model_filename,
+        featuresets,
+        classifier="naivebayes",
+        options=[],
+        quiet=True,
+    ):
         # Make sure we can find java & weka.
         config_weka()
 
@@ -187,7 +218,7 @@ class WekaClassifier(ClassifierI):
         temp_dir = tempfile.mkdtemp()
         try:
             # Write the training data file.
-            train_filename = os.path.join(temp_dir, 'train.arff')
+            train_filename = os.path.join(temp_dir, "train.arff")
             formatter.write(train_filename, featuresets)
 
             if classifier in cls._CLASSIFIER_CLASS:
@@ -195,14 +226,15 @@ class WekaClassifier(ClassifierI):
             elif classifier in cls._CLASSIFIER_CLASS.values():
                 javaclass = classifier
             else:
-                raise ValueError('Unknown classifier %s' % classifier)
+                raise ValueError("Unknown classifier %s" % classifier)
 
             # Train the weka model.
-            cmd = [javaclass, '-d', model_filename, '-t', train_filename]
+            cmd = [javaclass, "-d", model_filename, "-t", train_filename]
             cmd += list(options)
             if quiet:
                 stdout = subprocess.PIPE
-            else: stdout = None
+            else:
+                stdout = None
             java(cmd, classpath=_weka_classpath, stdout=stdout)
 
             # Return the new classifier.
@@ -244,8 +276,8 @@ class ARFF_Formatter:
 
     def write(self, outfile, tokens):
         """Writes ARFF data to a file for the given data."""
-        if not hasattr(outfile, 'write'):
-            outfile = open(outfile, 'w')
+        if not hasattr(outfile, "write"):
+            outfile = open(outfile, "w")
         outfile.write(self.format(tokens))
         outfile.close()
 
@@ -264,18 +296,18 @@ class ARFF_Formatter:
         for tok, label in tokens:
             for (fname, fval) in tok.items():
                 if issubclass(type(fval), bool):
-                    ftype = '{True, False}'
-                elif issubclass(type(fval), (compat.integer_types, float, bool)):
-                    ftype = 'NUMERIC'
-                elif issubclass(type(fval), compat.string_types):
-                    ftype = 'STRING'
+                    ftype = "{True, False}"
+                elif issubclass(type(fval), (int, float, bool)):
+                    ftype = "NUMERIC"
+                elif issubclass(type(fval), str):
+                    ftype = "STRING"
                 elif fval is None:
-                    continue # can't tell the type.
+                    continue  # can't tell the type.
                 else:
-                    raise ValueError('Unsupported value type %r' % ftype)
+                    raise ValueError("Unsupported value type %r" % ftype)
 
                 if features.get(fname, ftype) != ftype:
-                    raise ValueError('Inconsistent type for %s' % fname)
+                    raise ValueError("Inconsistent type for %s" % fname)
                 features[fname] = ftype
         features = sorted(features.items())
 
@@ -284,19 +316,21 @@ class ARFF_Formatter:
     def header_section(self):
         """Returns an ARFF header as a string."""
         # Header comment.
-        s = ('% Weka ARFF file\n' +
-             '% Generated automatically by NLTK\n' +
-             '%% %s\n\n' % time.ctime())
+        s = (
+            "% Weka ARFF file\n"
+            + "% Generated automatically by NLTK\n"
+            + "%% %s\n\n" % time.ctime()
+        )
 
         # Relation name
-        s += '@RELATION rel\n\n'
+        s += "@RELATION rel\n\n"
 
         # Input attribute specifications
         for fname, ftype in self._features:
-            s += '@ATTRIBUTE %-30r %s\n' % (fname, ftype)
+            s += "@ATTRIBUTE %-30r %s\n" % (fname, ftype)
 
         # Label attribute specification
-        s += '@ATTRIBUTE %-30r {%s}\n' % ('-label-', ','.join(self._labels))
+        s += "@ATTRIBUTE %-30r {%s}\n" % ("-label-", ",".join(self._labels))
 
         return s
 
@@ -318,28 +352,29 @@ class ARFF_Formatter:
             tokens = [(tok, None) for tok in tokens]
 
         # Data section
-        s = '\n@DATA\n'
+        s = "\n@DATA\n"
         for (tok, label) in tokens:
             for fname, ftype in self._features:
-                s += '%s,' % self._fmt_arff_val(tok.get(fname))
-            s += '%s\n' % self._fmt_arff_val(label)
+                s += "%s," % self._fmt_arff_val(tok.get(fname))
+            s += "%s\n" % self._fmt_arff_val(label)
 
         return s
 
     def _fmt_arff_val(self, fval):
         if fval is None:
-            return '?'
-        elif isinstance(fval, (bool, compat.integer_types)):
-            return '%s' % fval
+            return "?"
+        elif isinstance(fval, (bool, int)):
+            return "%s" % fval
         elif isinstance(fval, float):
-            return '%r' % fval
+            return "%r" % fval
         else:
-            return '%r' % fval
+            return "%r" % fval
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     from nltk.classify.util import names_demo, binary_names_demo_features
+
     def make_classifier(featuresets):
-        return WekaClassifier.train('/tmp/name.model', featuresets,
-                                    'C4.5')
+        return WekaClassifier.train("/tmp/name.model", featuresets, "C4.5")
+
     classifier = names_demo(make_classifier, binary_names_demo_features)
