@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Plaintext Corpus Reader
 #
-# Copyright (C) 2001-2014 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Steven Bird <stevenbird1@gmail.com>
 #         Edward Loper <edloper@gmail.com>
 #         Nitin Madnani <nmadnani@umiacs.umd.edu>
@@ -11,15 +11,13 @@
 A reader for corpora that consist of plaintext documents.
 """
 
-import codecs
-
 import nltk.data
-from nltk.compat import string_types
 from nltk.tokenize import *
 
 from nltk.corpus.reader.util import *
 from nltk.corpus.reader.api import *
 
+
 class PlaintextCorpusReader(CorpusReader):
     """
     Reader for corpora that consist of plaintext documents.  Paragraphs
@@ -37,12 +35,15 @@ class PlaintextCorpusReader(CorpusReader):
        ``PlaintextCorpusReader`` may specify alternative corpus view
        classes (e.g., to skip the preface sections of documents.)"""
 
-    def __init__(self, root, fileids,
-                 word_tokenizer=WordPunctTokenizer(),
-                 sent_tokenizer=nltk.data.LazyLoader(
-                     'tokenizers/punkt/english.pickle'),
-                 para_block_reader=read_blankline_block,
-                 encoding='utf8'):
+    def __init__(
+        self,
+        root,
+        fileids,
+        word_tokenizer=WordPunctTokenizer(),
+        sent_tokenizer=nltk.data.LazyLoader("tokenizers/punkt/english.pickle"),
+        para_block_reader=read_blankline_block,
+        encoding="utf8",
+    ):
         """
         Construct a new plaintext corpus reader for a set of documents
         located at the given root directory.  Example usage:
@@ -69,9 +70,16 @@ class PlaintextCorpusReader(CorpusReader):
         :return: the given file(s) as a single string.
         :rtype: str
         """
-        if fileids is None: fileids = self._fileids
-        elif isinstance(fileids, string_types): fileids = [fileids]
-        return concat([self.open(f).read() for f in fileids])
+        if fileids is None:
+            fileids = self._fileids
+        elif isinstance(fileids, str):
+            fileids = [fileids]
+        raw_texts = []
+        for f in fileids:
+            _fin = self.open(f)
+            raw_texts.append(_fin.read())
+            _fin.close()
+        return concat(raw_texts)
 
     def words(self, fileids=None):
         """
@@ -79,9 +87,12 @@ class PlaintextCorpusReader(CorpusReader):
             and punctuation symbols.
         :rtype: list(str)
         """
-        return concat([self.CorpusView(path, self._read_word_block, encoding=enc)
-                       for (path, enc, fileid)
-                       in self.abspaths(fileids, True, True)])
+        return concat(
+            [
+                self.CorpusView(path, self._read_word_block, encoding=enc)
+                for (path, enc, fileid) in self.abspaths(fileids, True, True)
+            ]
+        )
 
     def sents(self, fileids=None):
         """
@@ -91,11 +102,14 @@ class PlaintextCorpusReader(CorpusReader):
         :rtype: list(list(str))
         """
         if self._sent_tokenizer is None:
-            raise ValueError('No sentence tokenizer for this corpus')
+            raise ValueError("No sentence tokenizer for this corpus")
 
-        return concat([self.CorpusView(path, self._read_sent_block, encoding=enc)
-                       for (path, enc, fileid)
-                       in self.abspaths(fileids, True, True)])
+        return concat(
+            [
+                self.CorpusView(path, self._read_sent_block, encoding=enc)
+                for (path, enc, fileid) in self.abspaths(fileids, True, True)
+            ]
+        )
 
     def paras(self, fileids=None):
         """
@@ -105,39 +119,50 @@ class PlaintextCorpusReader(CorpusReader):
         :rtype: list(list(list(str)))
         """
         if self._sent_tokenizer is None:
-            raise ValueError('No sentence tokenizer for this corpus')
+            raise ValueError("No sentence tokenizer for this corpus")
 
-        return concat([self.CorpusView(path, self._read_para_block, encoding=enc)
-                       for (path, enc, fileid)
-                       in self.abspaths(fileids, True, True)])
+        return concat(
+            [
+                self.CorpusView(path, self._read_para_block, encoding=enc)
+                for (path, enc, fileid) in self.abspaths(fileids, True, True)
+            ]
+        )
 
     def _read_word_block(self, stream):
         words = []
-        for i in range(20): # Read 20 lines at a time.
+        for i in range(20):  # Read 20 lines at a time.
             words.extend(self._word_tokenizer.tokenize(stream.readline()))
         return words
 
     def _read_sent_block(self, stream):
         sents = []
         for para in self._para_block_reader(stream):
-            sents.extend([self._word_tokenizer.tokenize(sent)
-                          for sent in self._sent_tokenizer.tokenize(para)])
+            sents.extend(
+                [
+                    self._word_tokenizer.tokenize(sent)
+                    for sent in self._sent_tokenizer.tokenize(para)
+                ]
+            )
         return sents
 
     def _read_para_block(self, stream):
         paras = []
         for para in self._para_block_reader(stream):
-            paras.append([self._word_tokenizer.tokenize(sent)
-                          for sent in self._sent_tokenizer.tokenize(para)])
+            paras.append(
+                [
+                    self._word_tokenizer.tokenize(sent)
+                    for sent in self._sent_tokenizer.tokenize(para)
+                ]
+            )
         return paras
 
 
-class CategorizedPlaintextCorpusReader(CategorizedCorpusReader,
-                                    PlaintextCorpusReader):
+class CategorizedPlaintextCorpusReader(CategorizedCorpusReader, PlaintextCorpusReader):
     """
     A reader for plaintext corpora whose documents are divided into
     categories based on their file identifiers.
     """
+
     def __init__(self, *args, **kwargs):
         """
         Initialize the corpus reader.  Categorization arguments
@@ -150,31 +175,37 @@ class CategorizedPlaintextCorpusReader(CategorizedCorpusReader,
 
     def _resolve(self, fileids, categories):
         if fileids is not None and categories is not None:
-            raise ValueError('Specify fileids or categories, not both')
+            raise ValueError("Specify fileids or categories, not both")
         if categories is not None:
             return self.fileids(categories)
         else:
             return fileids
-    def raw(self, fileids=None, categories=None):
-        return PlaintextCorpusReader.raw(
-            self, self._resolve(fileids, categories))
-    def words(self, fileids=None, categories=None):
-        return PlaintextCorpusReader.words(
-            self, self._resolve(fileids, categories))
-    def sents(self, fileids=None, categories=None):
-        return PlaintextCorpusReader.sents(
-            self, self._resolve(fileids, categories))
-    def paras(self, fileids=None, categories=None):
-        return PlaintextCorpusReader.paras(
-            self, self._resolve(fileids, categories))
 
-# is there a better way?
+    def raw(self, fileids=None, categories=None):
+        return PlaintextCorpusReader.raw(self, self._resolve(fileids, categories))
+
+    def words(self, fileids=None, categories=None):
+        return PlaintextCorpusReader.words(self, self._resolve(fileids, categories))
+
+    def sents(self, fileids=None, categories=None):
+        return PlaintextCorpusReader.sents(self, self._resolve(fileids, categories))
+
+    def paras(self, fileids=None, categories=None):
+        return PlaintextCorpusReader.paras(self, self._resolve(fileids, categories))
+
+
+# FIXME: Is there a better way? How to not hardcode this?
+#       Possibly, add a language kwargs to CategorizedPlaintextCorpusReader to
+#       override the `sent_tokenizer`.
 class PortugueseCategorizedPlaintextCorpusReader(CategorizedPlaintextCorpusReader):
     def __init__(self, *args, **kwargs):
         CategorizedCorpusReader.__init__(self, kwargs)
-        kwargs['sent_tokenizer'] = nltk.data.LazyLoader('tokenizers/punkt/portuguese.pickle')
+        kwargs["sent_tokenizer"] = nltk.data.LazyLoader(
+            "tokenizers/punkt/portuguese.pickle"
+        )
         PlaintextCorpusReader.__init__(self, *args, **kwargs)
 
+
 class EuroparlCorpusReader(PlaintextCorpusReader):
 
     """
@@ -196,7 +227,7 @@ class EuroparlCorpusReader(PlaintextCorpusReader):
 
     def _read_word_block(self, stream):
         words = []
-        for i in range(20): # Read 20 lines at a time.
+        for i in range(20):  # Read 20 lines at a time.
             words.extend(stream.readline().split())
         return words
 
@@ -219,10 +250,14 @@ class EuroparlCorpusReader(PlaintextCorpusReader):
             in turn encoded as lists of word strings.
         :rtype: list(list(list(str)))
         """
-        return concat([self.CorpusView(fileid, self._read_para_block,
-                                       encoding=enc)
-                       for (fileid, enc) in self.abspaths(fileids, True)])
+        return concat(
+            [
+                self.CorpusView(fileid, self._read_para_block, encoding=enc)
+                for (fileid, enc) in self.abspaths(fileids, True)
+            ]
+        )
 
     def paras(self, fileids=None):
-        raise NotImplementedError('The Europarl corpus reader does not support paragraphs. Please use chapters() instead.')
-
+        raise NotImplementedError(
+            "The Europarl corpus reader does not support paragraphs. Please use chapters() instead."
+        )
