@@ -1,6 +1,6 @@
 # Natural Language Toolkit: CFG visualization
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -48,8 +48,7 @@ Visualization tools for CFGs.
 
 import re
 
-from six import string_types
-from six.moves.tkinter import (
+from tkinter import (
     Button,
     Canvas,
     Entry,
@@ -79,24 +78,24 @@ from nltk.draw.util import (
 
 
 class ProductionList(ColorizedList):
-    ARROW = SymbolWidget.SYMBOLS['rightarrow']
+    ARROW = SymbolWidget.SYMBOLS["rightarrow"]
 
     def _init_colortags(self, textwidget, options):
-        textwidget.tag_config('terminal', foreground='#006000')
-        textwidget.tag_config('arrow', font='symbol', underline='0')
+        textwidget.tag_config("terminal", foreground="#006000")
+        textwidget.tag_config("arrow", font="symbol", underline="0")
         textwidget.tag_config(
-            'nonterminal', foreground='blue', font=('helvetica', -12, 'bold')
+            "nonterminal", foreground="blue", font=("helvetica", -12, "bold")
         )
 
     def _item_repr(self, item):
         contents = []
-        contents.append(('%s\t' % item.lhs(), 'nonterminal'))
-        contents.append((self.ARROW, 'arrow'))
+        contents.append(("%s\t" % item.lhs(), "nonterminal"))
+        contents.append((self.ARROW, "arrow"))
         for elt in item.rhs():
             if isinstance(elt, Nonterminal):
-                contents.append((' %s' % elt.symbol(), 'nonterminal'))
+                contents.append((" %s" % elt.symbol(), "nonterminal"))
             else:
-                contents.append((' %r' % elt, 'terminal'))
+                contents.append((" %r" % elt, "terminal"))
         return contents
 
 
@@ -161,7 +160,7 @@ class CFGEditor(object):
 
     # Regular expressions used by _analyze_line.  Precompile them, so
     # we can process the text faster.
-    ARROW = SymbolWidget.SYMBOLS['rightarrow']
+    ARROW = SymbolWidget.SYMBOLS["rightarrow"]
     _LHS_RE = re.compile(r"(^\s*\w+\s*)(->|(" + ARROW + "))")
     _ARROW_RE = re.compile("\s*(->|(" + ARROW + "))\s*")
     _PRODUCTION_RE = re.compile(
@@ -172,14 +171,14 @@ class CFGEditor(object):
         + r"((\w+|'[\w ]*'|\"[\w ]*\"|\|)\s*)*$"  # arrow
     )  # RHS
     _TOKEN_RE = re.compile("\\w+|->|'[\\w ]+'|\"[\\w ]+\"|(" + ARROW + ")")
-    _BOLD = ('helvetica', -12, 'bold')
+    _BOLD = ("helvetica", -12, "bold")
 
     def __init__(self, parent, cfg=None, set_cfg_callback=None):
         self._parent = parent
         if cfg is not None:
             self._cfg = cfg
         else:
-            self._cfg = CFG(Nonterminal('S'), [])
+            self._cfg = CFG(Nonterminal("S"), [])
         self._set_cfg_callback = set_cfg_callback
 
         self._highlight_matching_nonterminals = 1
@@ -189,97 +188,97 @@ class CFGEditor(object):
         self._init_bindings()
 
         self._init_startframe()
-        self._startframe.pack(side='top', fill='x', expand=0)
+        self._startframe.pack(side="top", fill="x", expand=0)
         self._init_prodframe()
-        self._prodframe.pack(side='top', fill='both', expand=1)
+        self._prodframe.pack(side="top", fill="both", expand=1)
         self._init_buttons()
-        self._buttonframe.pack(side='bottom', fill='x', expand=0)
+        self._buttonframe.pack(side="bottom", fill="x", expand=0)
 
         self._textwidget.focus()
 
     def _init_startframe(self):
         frame = self._startframe = Frame(self._top)
         self._start = Entry(frame)
-        self._start.pack(side='right')
-        Label(frame, text='Start Symbol:').pack(side='right')
-        Label(frame, text='Productions:').pack(side='left')
+        self._start.pack(side="right")
+        Label(frame, text="Start Symbol:").pack(side="right")
+        Label(frame, text="Productions:").pack(side="left")
         self._start.insert(0, self._cfg.start().symbol())
 
     def _init_buttons(self):
         frame = self._buttonframe = Frame(self._top)
-        Button(frame, text='Ok', command=self._ok, underline=0, takefocus=0).pack(
-            side='left'
+        Button(frame, text="Ok", command=self._ok, underline=0, takefocus=0).pack(
+            side="left"
         )
-        Button(frame, text='Apply', command=self._apply, underline=0, takefocus=0).pack(
-            side='left'
+        Button(frame, text="Apply", command=self._apply, underline=0, takefocus=0).pack(
+            side="left"
         )
-        Button(frame, text='Reset', command=self._reset, underline=0, takefocus=0).pack(
-            side='left'
+        Button(frame, text="Reset", command=self._reset, underline=0, takefocus=0).pack(
+            side="left"
         )
         Button(
-            frame, text='Cancel', command=self._cancel, underline=0, takefocus=0
-        ).pack(side='left')
-        Button(frame, text='Help', command=self._help, underline=0, takefocus=0).pack(
-            side='right'
+            frame, text="Cancel", command=self._cancel, underline=0, takefocus=0
+        ).pack(side="left")
+        Button(frame, text="Help", command=self._help, underline=0, takefocus=0).pack(
+            side="right"
         )
 
     def _init_bindings(self):
-        self._top.title('CFG Editor')
-        self._top.bind('<Control-q>', self._cancel)
-        self._top.bind('<Alt-q>', self._cancel)
-        self._top.bind('<Control-d>', self._cancel)
+        self._top.title("CFG Editor")
+        self._top.bind("<Control-q>", self._cancel)
+        self._top.bind("<Alt-q>", self._cancel)
+        self._top.bind("<Control-d>", self._cancel)
         # self._top.bind('<Control-x>', self._cancel)
-        self._top.bind('<Alt-x>', self._cancel)
-        self._top.bind('<Escape>', self._cancel)
+        self._top.bind("<Alt-x>", self._cancel)
+        self._top.bind("<Escape>", self._cancel)
         # self._top.bind('<Control-c>', self._cancel)
-        self._top.bind('<Alt-c>', self._cancel)
+        self._top.bind("<Alt-c>", self._cancel)
 
-        self._top.bind('<Control-o>', self._ok)
-        self._top.bind('<Alt-o>', self._ok)
-        self._top.bind('<Control-a>', self._apply)
-        self._top.bind('<Alt-a>', self._apply)
-        self._top.bind('<Control-r>', self._reset)
-        self._top.bind('<Alt-r>', self._reset)
-        self._top.bind('<Control-h>', self._help)
-        self._top.bind('<Alt-h>', self._help)
-        self._top.bind('<F1>', self._help)
+        self._top.bind("<Control-o>", self._ok)
+        self._top.bind("<Alt-o>", self._ok)
+        self._top.bind("<Control-a>", self._apply)
+        self._top.bind("<Alt-a>", self._apply)
+        self._top.bind("<Control-r>", self._reset)
+        self._top.bind("<Alt-r>", self._reset)
+        self._top.bind("<Control-h>", self._help)
+        self._top.bind("<Alt-h>", self._help)
+        self._top.bind("<F1>", self._help)
 
     def _init_prodframe(self):
         self._prodframe = Frame(self._top)
 
         # Create the basic Text widget & scrollbar.
         self._textwidget = Text(
-            self._prodframe, background='#e0e0e0', exportselection=1
+            self._prodframe, background="#e0e0e0", exportselection=1
         )
-        self._textscroll = Scrollbar(self._prodframe, takefocus=0, orient='vertical')
+        self._textscroll = Scrollbar(self._prodframe, takefocus=0, orient="vertical")
         self._textwidget.config(yscrollcommand=self._textscroll.set)
         self._textscroll.config(command=self._textwidget.yview)
-        self._textscroll.pack(side='right', fill='y')
-        self._textwidget.pack(expand=1, fill='both', side='left')
+        self._textscroll.pack(side="right", fill="y")
+        self._textwidget.pack(expand=1, fill="both", side="left")
 
         # Initialize the colorization tags.  Each nonterminal gets its
         # own tag, so they aren't listed here.
-        self._textwidget.tag_config('terminal', foreground='#006000')
-        self._textwidget.tag_config('arrow', font='symbol')
-        self._textwidget.tag_config('error', background='red')
+        self._textwidget.tag_config("terminal", foreground="#006000")
+        self._textwidget.tag_config("arrow", font="symbol")
+        self._textwidget.tag_config("error", background="red")
 
         # Keep track of what line they're on.  We use that to remember
         # to re-analyze a line whenever they leave it.
         self._linenum = 0
 
         # Expand "->" to an arrow.
-        self._top.bind('>', self._replace_arrows)
+        self._top.bind(">", self._replace_arrows)
 
         # Re-colorize lines when appropriate.
-        self._top.bind('<<Paste>>', self._analyze)
-        self._top.bind('<KeyPress>', self._check_analyze)
-        self._top.bind('<ButtonPress>', self._check_analyze)
+        self._top.bind("<<Paste>>", self._analyze)
+        self._top.bind("<KeyPress>", self._check_analyze)
+        self._top.bind("<ButtonPress>", self._check_analyze)
 
         # Tab cycles focus. (why doesn't this work??)
         def cycle(e, textwidget=self._textwidget):
             textwidget.tk_focusNext().focus()
 
-        self._textwidget.bind('<Tab>', cycle)
+        self._textwidget.bind("<Tab>", cycle)
 
         prod_tuples = [(p.lhs(), [p.rhs()]) for p in self._cfg.productions()]
         for i in range(len(prod_tuples) - 1, 0, -1):
@@ -295,16 +294,16 @@ class CFGEditor(object):
 
         for lhs, rhss in prod_tuples:
             print(lhs, rhss)
-            s = '%s ->' % lhs
+            s = "%s ->" % lhs
             for rhs in rhss:
                 for elt in rhs:
                     if isinstance(elt, Nonterminal):
-                        s += ' %s' % elt
+                        s += " %s" % elt
                     else:
-                        s += ' %r' % elt
-                s += ' |'
-            s = s[:-2] + '\n'
-            self._textwidget.insert('end', s)
+                        s += " %r" % elt
+                s += " |"
+            s = s[:-2] + "\n"
+            self._textwidget.insert("end", s)
 
         self._analyze()
 
@@ -338,10 +337,10 @@ class CFGEditor(object):
         Remove all tags (except ``arrow`` and ``sel``) from the given
         line of the text widget used for editing the productions.
         """
-        start = '%d.0' % linenum
-        end = '%d.end' % linenum
+        start = "%d.0" % linenum
+        end = "%d.end" % linenum
         for tag in self._textwidget.tag_names():
-            if tag not in ('arrow', 'sel'):
+            if tag not in ("arrow", "sel"):
                 self._textwidget.tag_remove(tag, start, end)
 
     def _check_analyze(self, *e):
@@ -350,7 +349,7 @@ class CFGEditor(object):
         all colorization from the line we moved to, and re-colorize
         the line that we moved from.
         """
-        linenum = int(self._textwidget.index('insert').split('.')[0])
+        linenum = int(self._textwidget.index("insert").split(".")[0])
         if linenum != self._linenum:
             self._clear_tags(linenum)
             self._analyze_line(self._linenum)
@@ -362,21 +361,21 @@ class CFGEditor(object):
         symbol font).  This searches the whole buffer, but is fast
         enough to be done anytime they press '>'.
         """
-        arrow = '1.0'
+        arrow = "1.0"
         while True:
-            arrow = self._textwidget.search('->', arrow, 'end+1char')
-            if arrow == '':
+            arrow = self._textwidget.search("->", arrow, "end+1char")
+            if arrow == "":
                 break
-            self._textwidget.delete(arrow, arrow + '+2char')
-            self._textwidget.insert(arrow, self.ARROW, 'arrow')
-            self._textwidget.insert(arrow, '\t')
+            self._textwidget.delete(arrow, arrow + "+2char")
+            self._textwidget.insert(arrow, self.ARROW, "arrow")
+            self._textwidget.insert(arrow, "\t")
 
-        arrow = '1.0'
+        arrow = "1.0"
         while True:
-            arrow = self._textwidget.search(self.ARROW, arrow + '+1char', 'end+1char')
-            if arrow == '':
+            arrow = self._textwidget.search(self.ARROW, arrow + "+1char", "end+1char")
+            if arrow == "":
                 break
-            self._textwidget.tag_add('arrow', arrow, arrow + '+1char')
+            self._textwidget.tag_add("arrow", arrow, arrow + "+1char")
 
     def _analyze_token(self, match, linenum):
         """
@@ -387,34 +386,34 @@ class CFGEditor(object):
         """
         # What type of token is it?
         if match.group()[0] in "'\"":
-            tag = 'terminal'
-        elif match.group() in ('->', self.ARROW):
-            tag = 'arrow'
+            tag = "terminal"
+        elif match.group() in ("->", self.ARROW):
+            tag = "arrow"
         else:
             # If it's a nonterminal, then set up new bindings, so we
             # can highlight all instances of that nonterminal when we
             # put the mouse over it.
-            tag = 'nonterminal_' + match.group()
+            tag = "nonterminal_" + match.group()
             if tag not in self._textwidget.tag_names():
                 self._init_nonterminal_tag(tag)
 
-        start = '%d.%d' % (linenum, match.start())
-        end = '%d.%d' % (linenum, match.end())
+        start = "%d.%d" % (linenum, match.start())
+        end = "%d.%d" % (linenum, match.end())
         self._textwidget.tag_add(tag, start, end)
 
-    def _init_nonterminal_tag(self, tag, foreground='blue'):
+    def _init_nonterminal_tag(self, tag, foreground="blue"):
         self._textwidget.tag_config(tag, foreground=foreground, font=CFGEditor._BOLD)
         if not self._highlight_matching_nonterminals:
             return
 
         def enter(e, textwidget=self._textwidget, tag=tag):
-            textwidget.tag_config(tag, background='#80ff80')
+            textwidget.tag_config(tag, background="#80ff80")
 
         def leave(e, textwidget=self._textwidget, tag=tag):
-            textwidget.tag_config(tag, background='')
+            textwidget.tag_config(tag, background="")
 
-        self._textwidget.tag_bind(tag, '<Enter>', enter)
-        self._textwidget.tag_bind(tag, '<Leave>', leave)
+        self._textwidget.tag_bind(tag, "<Enter>", enter)
+        self._textwidget.tag_bind(tag, "<Leave>", leave)
 
     def _analyze_line(self, linenum):
         """
@@ -424,7 +423,7 @@ class CFGEditor(object):
         self._clear_tags(linenum)
 
         # Get the line line's text string.
-        line = self._textwidget.get(repr(linenum) + '.0', repr(linenum) + '.end')
+        line = self._textwidget.get(repr(linenum) + ".0", repr(linenum) + ".end")
 
         # If it's a valid production, then colorize each token.
         if CFGEditor._PRODUCTION_RE.match(line):
@@ -432,10 +431,10 @@ class CFGEditor(object):
             # and call analyze_token on each token.
             def analyze_token(match, self=self, linenum=linenum):
                 self._analyze_token(match, linenum)
-                return ''
+                return ""
 
             CFGEditor._TOKEN_RE.sub(analyze_token, line)
-        elif line.strip() != '':
+        elif line.strip() != "":
             # It's invalid; show the user where the error is.
             self._mark_error(linenum, line)
 
@@ -446,29 +445,29 @@ class CFGEditor(object):
         arrowmatch = CFGEditor._ARROW_RE.search(line)
         if not arrowmatch:
             # If there's no arrow at all, highlight the whole line.
-            start = '%d.0' % linenum
-            end = '%d.end' % linenum
+            start = "%d.0" % linenum
+            end = "%d.end" % linenum
         elif not CFGEditor._LHS_RE.match(line):
             # Otherwise, if the LHS is bad, highlight it.
-            start = '%d.0' % linenum
-            end = '%d.%d' % (linenum, arrowmatch.start())
+            start = "%d.0" % linenum
+            end = "%d.%d" % (linenum, arrowmatch.start())
         else:
             # Otherwise, highlight the RHS.
-            start = '%d.%d' % (linenum, arrowmatch.end())
-            end = '%d.end' % linenum
+            start = "%d.%d" % (linenum, arrowmatch.end())
+            end = "%d.end" % linenum
 
         # If we're highlighting 0 chars, highlight the whole line.
-        if self._textwidget.compare(start, '==', end):
-            start = '%d.0' % linenum
-            end = '%d.end' % linenum
-        self._textwidget.tag_add('error', start, end)
+        if self._textwidget.compare(start, "==", end):
+            start = "%d.0" % linenum
+            end = "%d.end" % linenum
+        self._textwidget.tag_add("error", start, end)
 
     def _analyze(self, *e):
         """
         Replace ``->`` with arrows, and colorize the entire buffer.
         """
         self._replace_arrows()
-        numlines = int(self._textwidget.index('end').split('.')[0])
+        numlines = int(self._textwidget.index("end").split(".")[0])
         for linenum in range(1, numlines + 1):  # line numbers start at 1.
             self._analyze_line(linenum)
 
@@ -480,15 +479,15 @@ class CFGEditor(object):
         productions = []
 
         # Get the text, normalize it, and split it into lines.
-        text = self._textwidget.get('1.0', 'end')
-        text = re.sub(self.ARROW, '->', text)
-        text = re.sub('\t', ' ', text)
-        lines = text.split('\n')
+        text = self._textwidget.get("1.0", "end")
+        text = re.sub(self.ARROW, "->", text)
+        text = re.sub("\t", " ", text)
+        lines = text.split("\n")
 
         # Convert each line to a CFG production
         for line in lines:
             line = line.strip()
-            if line == '':
+            if line == "":
                 continue
             productions += _read_cfg_production(line)
             # if line.strip() == '': continue
@@ -527,9 +526,9 @@ class CFGEditor(object):
             self._set_cfg_callback(cfg)
 
     def _reset(self, *e):
-        self._textwidget.delete('1.0', 'end')
+        self._textwidget.delete("1.0", "end")
         for production in self._cfg.productions():
-            self._textwidget.insert('end', '%s\n' % production)
+            self._textwidget.insert("end", "%s\n" % production)
         self._analyze()
         if self._set_cfg_callback is not None:
             self._set_cfg_callback(self._cfg)
@@ -546,15 +545,15 @@ class CFGEditor(object):
         try:
             ShowText(
                 self._parent,
-                'Help: Chart Parser Demo',
+                "Help: Chart Parser Demo",
                 (_CFGEditor_HELP).strip(),
                 width=75,
-                font='fixed',
+                font="fixed",
             )
         except:
             ShowText(
                 self._parent,
-                'Help: Chart Parser Demo',
+                "Help: Chart Parser Demo",
                 (_CFGEditor_HELP).strip(),
                 width=75,
             )
@@ -572,7 +571,7 @@ class CFGDemo(object):
 
         # Set up the main window.
         self._top = Tk()
-        self._top.title('Context Free Grammar Demo')
+        self._top.title("Context Free Grammar Demo")
 
         # Base font size
         self._size = IntVar(self._top)
@@ -583,7 +582,7 @@ class CFGDemo(object):
 
         # Create the basic frames
         frame1 = Frame(self._top)
-        frame1.pack(side='left', fill='y', expand=0)
+        frame1.pack(side="left", fill="y", expand=0)
         self._init_menubar(self._top)
         self._init_buttons(self._top)
         self._init_grammar(frame1)
@@ -595,7 +594,7 @@ class CFGDemo(object):
     # //////////////////////////////////////////////////
 
     def _init_bindings(self, top):
-        top.bind('<Control-q>', self.destroy)
+        top.bind("<Control-q>", self.destroy)
 
     def _init_menubar(self, parent):
         pass
@@ -605,19 +604,19 @@ class CFGDemo(object):
 
     def _init_grammar(self, parent):
         self._prodlist = ProductionList(parent, self._grammar, width=20)
-        self._prodlist.pack(side='top', fill='both', expand=1)
+        self._prodlist.pack(side="top", fill="both", expand=1)
         self._prodlist.focus()
-        self._prodlist.add_callback('select', self._selectprod_cb)
-        self._prodlist.add_callback('move', self._selectprod_cb)
+        self._prodlist.add_callback("select", self._selectprod_cb)
+        self._prodlist.add_callback("move", self._selectprod_cb)
 
     def _init_treelet(self, parent):
-        self._treelet_canvas = Canvas(parent, background='white')
-        self._treelet_canvas.pack(side='bottom', fill='x')
+        self._treelet_canvas = Canvas(parent, background="white")
+        self._treelet_canvas.pack(side="bottom", fill="x")
         self._treelet = None
 
     def _init_workspace(self, parent):
-        self._workspace = CanvasFrame(parent, background='white')
-        self._workspace.pack(side='right', fill='both', expand=1)
+        self._workspace = CanvasFrame(parent, background="white")
+        self._workspace.pack(side="right", fill="both", expand=1)
         self._tree = None
         self.reset_workspace()
 
@@ -628,8 +627,8 @@ class CFGDemo(object):
     def reset_workspace(self):
         c = self._workspace.canvas()
         fontsize = int(self._size.get())
-        node_font = ('helvetica', -(fontsize + 4), 'bold')
-        leaf_font = ('helvetica', -(fontsize + 2))
+        node_font = ("helvetica", -(fontsize + 4), "bold")
+        leaf_font = ("helvetica", -(fontsize + 2))
 
         # Remove the old tree
         if self._tree is not None:
@@ -645,7 +644,7 @@ class CFGDemo(object):
             leaves.append(TextWidget(c, word, font=leaf_font, draggable=1))
 
         # Put it all together into one tree
-        self._tree = TreeSegmentWidget(c, rootnode, leaves, color='white')
+        self._tree = TreeSegmentWidget(c, rootnode, leaves, color="white")
 
         # Add it to the workspace.
         self._workspace.add_widget(self._tree)
@@ -664,7 +663,7 @@ class CFGDemo(object):
         if tree is None:
             tree = self._tree
         for i in range(len(tree.subtrees()) - len(prod.rhs())):
-            if tree['color', i] == 'white':
+            if tree["color", i] == "white":
                 self._markproduction  # FIXME: Is this necessary at all?
 
             for j, node in enumerate(prod.rhs()):
@@ -676,7 +675,7 @@ class CFGDemo(object):
                 ):
                     pass  # matching nonterminal
                 elif (
-                    isinstance(node, string_types)
+                    isinstance(node, str)
                     and isinstance(widget, TextWidget)
                     and node == widget.text()
                 ):
@@ -685,7 +684,7 @@ class CFGDemo(object):
                     break
             else:
                 # Everything matched!
-                print('MATCH AT', i)
+                print("MATCH AT", i)
 
     # //////////////////////////////////////////////////
     # Grammar
@@ -707,16 +706,16 @@ class CFGDemo(object):
 
         # Draw the tree in the treelet area.
         fontsize = int(self._size.get())
-        node_font = ('helvetica', -(fontsize + 4), 'bold')
-        leaf_font = ('helvetica', -(fontsize + 2))
+        node_font = ("helvetica", -(fontsize + 4), "bold")
+        leaf_font = ("helvetica", -(fontsize + 2))
         self._treelet = tree_to_treesegment(
             canvas, tree, node_font=node_font, leaf_font=leaf_font
         )
-        self._treelet['draggable'] = 1
+        self._treelet["draggable"] = 1
 
         # Center the treelet.
         (x1, y1, x2, y2) = self._treelet.bbox()
-        w, h = int(canvas['width']), int(canvas['height'])
+        w, h = int(canvas["width"]), int(canvas["height"])
         self._treelet.move((w - x1 - x2) / 2, (h - y1 - y2) / 2)
 
         # Mark the places where we can add it to the workspace.
@@ -732,7 +731,7 @@ class CFGDemo(object):
 def demo2():
     from nltk import Nonterminal, Production, CFG
 
-    nonterminals = 'S VP NP PP P N Name V Det'
+    nonterminals = "S VP NP PP P N Name V Det"
     (S, VP, NP, PP, P, N, Name, V, Det) = [Nonterminal(s) for s in nonterminals.split()]
     productions = (
         # Syntactic Productions
@@ -744,23 +743,23 @@ def demo2():
         Production(VP, [V, NP]),
         Production(PP, [P, NP]),
         Production(PP, []),
-        Production(PP, ['up', 'over', NP]),
+        Production(PP, ["up", "over", NP]),
         # Lexical Productions
-        Production(NP, ['I']),
-        Production(Det, ['the']),
-        Production(Det, ['a']),
-        Production(N, ['man']),
-        Production(V, ['saw']),
-        Production(P, ['in']),
-        Production(P, ['with']),
-        Production(N, ['park']),
-        Production(N, ['dog']),
-        Production(N, ['statue']),
-        Production(Det, ['my']),
+        Production(NP, ["I"]),
+        Production(Det, ["the"]),
+        Production(Det, ["a"]),
+        Production(N, ["man"]),
+        Production(V, ["saw"]),
+        Production(P, ["in"]),
+        Production(P, ["with"]),
+        Production(N, ["park"]),
+        Production(N, ["dog"]),
+        Production(N, ["statue"]),
+        Production(Det, ["my"]),
     )
     grammar = CFG(S, productions)
 
-    text = 'I saw a man in the park'.split()
+    text = "I saw a man in the park".split()
     d = CFGDemo(grammar, text)
     d.mainloop()
 
@@ -773,7 +772,7 @@ def demo2():
 def demo():
     from nltk import Nonterminal, CFG
 
-    nonterminals = 'S VP NP PP P N Name V Det'
+    nonterminals = "S VP NP PP P N Name V Det"
     (S, VP, NP, PP, P, N, Name, V, Det) = [Nonterminal(s) for s in nonterminals.split()]
 
     grammar = CFG.fromstring(
@@ -805,8 +804,8 @@ def demo():
 
     top = Tk()
     editor = CFGEditor(top, grammar, cb)
-    Label(top, text='\nTesting CFG Editor\n').pack()
-    Button(top, text='Quit', command=top.destroy).pack()
+    Label(top, text="\nTesting CFG Editor\n").pack()
+    Button(top, text="Quit", command=top.destroy).pack()
     top.mainloop()
 
 
@@ -814,7 +813,7 @@ def demo3():
     from nltk import Production
 
     (S, VP, NP, PP, P, N, Name, V, Det) = nonterminals(
-        'S, VP, NP, PP, P, N, Name, V, Det'
+        "S, VP, NP, PP, P, N, Name, V, Det"
     )
 
     productions = (
@@ -827,19 +826,19 @@ def demo3():
         Production(VP, [V, NP]),
         Production(PP, [P, NP]),
         Production(PP, []),
-        Production(PP, ['up', 'over', NP]),
+        Production(PP, ["up", "over", NP]),
         # Lexical Productions
-        Production(NP, ['I']),
-        Production(Det, ['the']),
-        Production(Det, ['a']),
-        Production(N, ['man']),
-        Production(V, ['saw']),
-        Production(P, ['in']),
-        Production(P, ['with']),
-        Production(N, ['park']),
-        Production(N, ['dog']),
-        Production(N, ['statue']),
-        Production(Det, ['my']),
+        Production(NP, ["I"]),
+        Production(Det, ["the"]),
+        Production(Det, ["a"]),
+        Production(N, ["man"]),
+        Production(V, ["saw"]),
+        Production(P, ["in"]),
+        Production(P, ["with"]),
+        Production(N, ["park"]),
+        Production(N, ["dog"]),
+        Production(N, ["statue"]),
+        Production(Det, ["my"]),
     )
 
     t = Tk()
@@ -847,15 +846,15 @@ def demo3():
     def destroy(e, t=t):
         t.destroy()
 
-    t.bind('q', destroy)
+    t.bind("q", destroy)
     p = ProductionList(t, productions)
-    p.pack(expand=1, fill='both')
-    p.add_callback('select', p.markonly)
-    p.add_callback('move', p.markonly)
+    p.pack(expand=1, fill="both")
+    p.add_callback("select", p.markonly)
+    p.add_callback("move", p.markonly)
     p.focus()
     p.mark(productions[2])
     p.mark(productions[8])
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     demo()
