@@ -2,16 +2,15 @@
 #
 # Author: Dan Garrette <dhgarrette@gmail.com>
 #
-# Copyright (C) 2001-2015 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
-from __future__ import print_function, division, unicode_literals
+
+from itertools import chain
 
 from nltk.internals import Counter
-from nltk.compat import python_2_unicode_compatible
 
 
-@python_2_unicode_compatible
 class FStructure(dict):
     def safeappend(self, key, item):
         """
@@ -37,18 +36,19 @@ class FStructure(dict):
 
     def to_depgraph(self, rel=None):
         from nltk.parse.dependencygraph import DependencyGraph
+
         depgraph = DependencyGraph()
         nodes = depgraph.nodes
 
-        self._to_depgraph(nodes, 0, 'ROOT')
+        self._to_depgraph(nodes, 0, "ROOT")
 
         # Add all the dependencies for all the nodes
         for address, node in nodes.items():
-            for n2 in (n for n in nodes.values() if n['rel'] != 'TOP'):
-                if n2['head'] == address:
-                    relation = n2['rel']
-                    node['deps'].setdefault(relation,[])
-                    node['deps'][relation].append(n2['address'])
+            for n2 in (n for n in nodes.values() if n["rel"] != "TOP"):
+                if n2["head"] == address:
+                    relation = n2["rel"]
+                    node["deps"].setdefault(relation, [])
+                    node["deps"][relation].append(n2["address"])
 
         depgraph.root = nodes[1]
 
@@ -59,11 +59,11 @@ class FStructure(dict):
 
         nodes[index].update(
             {
-                'address': index,
-                'word': self.pred[0],
-                'tag': self.pred[1],
-                'head': head,
-                'rel': rel,
+                "address": index,
+                "word": self.pred[0],
+                "tag": self.pred[1],
+                "head": head,
+                "rel": rel,
             }
         )
 
@@ -75,18 +75,20 @@ class FStructure(dict):
                     new_index = len(nodes)
                     nodes[new_index].update(
                         {
-                            'address': new_index,
-                            'word': item[0],
-                            'tag': item[1],
-                            'head': index,
-                            'rel': feature,
+                            "address": new_index,
+                            "word": item[0],
+                            "tag": item[1],
+                            "head": index,
+                            "rel": feature,
                         }
                     )
                 elif isinstance(item, list):
                     for n in item:
                         n._to_depgraph(nodes, index, feature)
                 else:
-                    raise Exception('feature %s is not an FStruct, a list, or a tuple' % feature)
+                    raise Exception(
+                        "feature %s is not an FStruct, a list, or a tuple" % feature
+                    )
 
     @staticmethod
     def read_depgraph(depgraph):
@@ -97,9 +99,9 @@ class FStructure(dict):
         if not label_counter:
             label_counter = Counter()
 
-        if node['rel'].lower() in ['spec', 'punct']:
+        if node["rel"].lower() in ["spec", "punct"]:
             # the value of a 'spec' entry is a word, not an FStructure
-            return (node['word'], node['tag'])
+            return (node["word"], node["tag"])
 
         else:
             fstruct = FStructure()
@@ -108,18 +110,21 @@ class FStructure(dict):
 
             fstruct.parent = parent
 
-            word, tag = node['word'], node['tag']
-            if tag[:2] == 'VB':
-                if tag[2:3] == 'D':
-                    fstruct.safeappend('tense', ('PAST', 'tense'))
+            word, tag = node["word"], node["tag"]
+            if tag[:2] == "VB":
+                if tag[2:3] == "D":
+                    fstruct.safeappend("tense", ("PAST", "tense"))
                 fstruct.pred = (word, tag[:2])
 
             if not fstruct.pred:
                 fstruct.pred = (word, tag)
 
-            children = [depgraph.nodes[idx] for idx in sum(list(node['deps'].values()), [])]
+            children = [depgraph.nodes[idx] for idx in chain(*node["deps"].values())]
             for child in children:
-                fstruct.safeappend(child['rel'], FStructure._read_depgraph(child, depgraph, label_counter, fstruct))
+                fstruct.safeappend(
+                    child["rel"],
+                    FStructure._read_depgraph(child, depgraph, label_counter, fstruct),
+                )
 
             return fstruct
 
@@ -131,8 +136,34 @@ class FStructure(dict):
         :param value: where to index into the list of characters
         :type value: int
         """
-        letter = ['f','g','h','i','j','k','l','m','n','o','p','q','r','s',
-                  't','u','v','w','x','y','z','a','b','c','d','e'][value-1]
+        letter = [
+            "f",
+            "g",
+            "h",
+            "i",
+            "j",
+            "k",
+            "l",
+            "m",
+            "n",
+            "o",
+            "p",
+            "q",
+            "r",
+            "s",
+            "t",
+            "u",
+            "v",
+            "w",
+            "x",
+            "y",
+            "z",
+            "a",
+            "b",
+            "c",
+            "d",
+            "e",
+        ][value - 1]
         num = int(value) // 26
         if num > 0:
             return letter + str(num)
@@ -140,39 +171,50 @@ class FStructure(dict):
             return letter
 
     def __repr__(self):
-        return self.__unicode__().replace('\n', '')
+        return self.__str__().replace("\n", "")
 
     def __str__(self):
         return self.pretty_format()
 
     def pretty_format(self, indent=3):
         try:
-            accum = '%s:[' % self.label
+            accum = "%s:[" % self.label
         except NameError:
-            accum = '['
+            accum = "["
         try:
-            accum += 'pred \'%s\'' % (self.pred[0])
+            accum += "pred '%s'" % (self.pred[0])
         except NameError:
             pass
 
         for feature in sorted(self):
             for item in self[feature]:
                 if isinstance(item, FStructure):
-                    next_indent = indent+len(feature)+3+len(self.label)
-                    accum += '\n%s%s %s' % (' '*(indent), feature, item.pretty_format(next_indent))
+                    next_indent = indent + len(feature) + 3 + len(self.label)
+                    accum += "\n%s%s %s" % (
+                        " " * (indent),
+                        feature,
+                        item.pretty_format(next_indent),
+                    )
                 elif isinstance(item, tuple):
-                    accum += '\n%s%s \'%s\'' % (' '*(indent), feature, item[0])
+                    accum += "\n%s%s '%s'" % (" " * (indent), feature, item[0])
                 elif isinstance(item, list):
-                    accum += '\n%s%s {%s}' % (' '*(indent), feature, ('\n%s' % (' '*(indent+len(feature)+2))).join(item))
-                else: # ERROR
-                    raise Exception('feature %s is not an FStruct, a list, or a tuple' % feature)
-        return accum+']'
-
+                    accum += "\n%s%s {%s}" % (
+                        " " * (indent),
+                        feature,
+                        ("\n%s" % (" " * (indent + len(feature) + 2))).join(item),
+                    )
+                else:  # ERROR
+                    raise Exception(
+                        "feature %s is not an FStruct, a list, or a tuple" % feature
+                    )
+        return accum + "]"
 
 
 def demo_read_depgraph():
     from nltk.parse.dependencygraph import DependencyGraph
-    dg1 = DependencyGraph("""\
+
+    dg1 = DependencyGraph(
+        """\
 Esso       NNP     2       SUB
 said       VBD     0       ROOT
 the        DT      5       NMOD
@@ -181,28 +223,36 @@ field      NN      6       SUB
 started    VBD     2       VMOD
 production NN      6       OBJ
 Tuesday    NNP     6       VMOD
-""")
-    dg2 = DependencyGraph("""\
+"""
+    )
+    dg2 = DependencyGraph(
+        """\
 John    NNP     2       SUB
 sees    VBP     0       ROOT
 Mary    NNP     2       OBJ
-""")
-    dg3 = DependencyGraph("""\
+"""
+    )
+    dg3 = DependencyGraph(
+        """\
 a       DT      2       SPEC
 man     NN      3       SUBJ
 walks   VB      0       ROOT
-""")
-    dg4 = DependencyGraph("""\
+"""
+    )
+    dg4 = DependencyGraph(
+        """\
 every   DT      2       SPEC
 girl    NN      3       SUBJ
 chases  VB      0       ROOT
 a       DT      5       SPEC
 dog     NN      3       OBJ
-""")
+"""
+    )
 
-    depgraphs = [dg1,dg2,dg3,dg4]
+    depgraphs = [dg1, dg2, dg3, dg4]
     for dg in depgraphs:
         print(FStructure.read_depgraph(dg))
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     demo_read_depgraph()
