@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Tagset Mapping
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2020 NLTK Project
 # Author: Nathan Schneider <nathan@cmu.edu>
 #         Steven Bird <stevenbird1@gmail.com>
 # URL: <http://nltk.org/>
@@ -29,7 +29,6 @@ X - other: foreign words, typos, abbreviations
 
 """
 
-from __future__ import print_function, unicode_literals, division
 from collections import defaultdict
 from os.path import join
 
@@ -37,44 +36,44 @@ from nltk.data import load
 
 _UNIVERSAL_DATA = "taggers/universal_tagset"
 _UNIVERSAL_TAGS = (
-    'VERB',
-    'NOUN',
-    'PRON',
-    'ADJ',
-    'ADV',
-    'ADP',
-    'CONJ',
-    'DET',
-    'NUM',
-    'PRT',
-    'X',
-    '.',
+    "VERB",
+    "NOUN",
+    "PRON",
+    "ADJ",
+    "ADV",
+    "ADP",
+    "CONJ",
+    "DET",
+    "NUM",
+    "PRT",
+    "X",
+    ".",
 )
 
 # _MAPPINGS = defaultdict(lambda: defaultdict(dict))
 # the mapping between tagset T1 and T2 returns UNK if appied to an unrecognized tag
-_MAPPINGS = defaultdict(lambda: defaultdict(lambda: defaultdict(lambda: 'UNK')))
+_MAPPINGS = defaultdict(lambda: defaultdict(lambda: defaultdict(lambda: "UNK")))
 
 
 def _load_universal_map(fileid):
-    contents = load(join(_UNIVERSAL_DATA, fileid + '.map'), format="text")
+    contents = load(join(_UNIVERSAL_DATA, fileid + ".map"), format="text")
 
     # When mapping to the Universal Tagset,
     # map unknown inputs to 'X' not 'UNK'
-    _MAPPINGS[fileid]['universal'].default_factory = lambda: 'X'
+    _MAPPINGS[fileid]["universal"].default_factory = lambda: "X"
 
     for line in contents.splitlines():
         line = line.strip()
-        if line == '':
+        if line == "":
             continue
-        fine, coarse = line.split('\t')
+        fine, coarse = line.split("\t")
 
-        assert coarse in _UNIVERSAL_TAGS, 'Unexpected coarse tag: {}'.format(coarse)
+        assert coarse in _UNIVERSAL_TAGS, "Unexpected coarse tag: {}".format(coarse)
         assert (
-            fine not in _MAPPINGS[fileid]['universal']
-        ), 'Multiple entries for original tag: {}'.format(fine)
+            fine not in _MAPPINGS[fileid]["universal"]
+        ), "Multiple entries for original tag: {}".format(fine)
 
-        _MAPPINGS[fileid]['universal'][fine] = coarse
+        _MAPPINGS[fileid]["universal"][fine] = coarse
 
 
 def tagset_mapping(source, target):
@@ -88,28 +87,28 @@ def tagset_mapping(source, target):
     """
 
     if source not in _MAPPINGS or target not in _MAPPINGS[source]:
-        if target == 'universal':
+        if target == "universal":
             _load_universal_map(source)
             # Added the new Russian National Corpus mappings because the
             # Russian model for nltk.pos_tag() uses it.
-            _MAPPINGS['ru-rnc-new']['universal'] = {
-                'A': 'ADJ',
-                'A-PRO': 'PRON',
-                'ADV': 'ADV',
-                'ADV-PRO': 'PRON',
-                'ANUM': 'ADJ',
-                'CONJ': 'CONJ',
-                'INTJ': 'X',
-                'NONLEX': '.',
-                'NUM': 'NUM',
-                'PARENTH': 'PRT',
-                'PART': 'PRT',
-                'PR': 'ADP',
-                'PRAEDIC': 'PRT',
-                'PRAEDIC-PRO': 'PRON',
-                'S': 'NOUN',
-                'S-PRO': 'PRON',
-                'V': 'VERB',
+            _MAPPINGS["ru-rnc-new"]["universal"] = {
+                "A": "ADJ",
+                "A-PRO": "PRON",
+                "ADV": "ADV",
+                "ADV-PRO": "PRON",
+                "ANUM": "ADJ",
+                "CONJ": "CONJ",
+                "INTJ": "X",
+                "NONLEX": ".",
+                "NUM": "NUM",
+                "PARENTH": "PRT",
+                "PART": "PRT",
+                "PR": "ADP",
+                "PRAEDIC": "PRT",
+                "PRAEDIC-PRO": "PRON",
+                "S": "NOUN",
+                "S-PRO": "PRON",
+                "V": "VERB",
             }
 
     return _MAPPINGS[source][target]
@@ -128,10 +127,10 @@ def map_tag(source, target, source_tag):
     """
 
     # we need a systematic approach to naming
-    if target == 'universal':
-        if source == 'wsj':
-            source = 'en-ptb'
-        if source == 'brown':
-            source = 'en-brown'
+    if target == "universal":
+        if source == "wsj":
+            source = "en-ptb"
+        if source == "brown":
+            source = "en-brown"
 
     return tagset_mapping(source, target)[source_tag]
