@@ -4,7 +4,6 @@ Unit tests for nltk.corpus.wordnet
 See also nltk/test/wordnet.doctest
 """
 
-from __future__ import unicode_literals
 
 import collections
 import os
@@ -198,13 +197,13 @@ class WordnNetDemo(unittest.TestCase):
         )
 
     def test_omw_lemma_no_trailing_underscore(self):
-        expected = [
+        expected = sorted([
             u'popolna_sprememba_v_mišljenju',
             u'popoln_obrat',
             u'preobrat',
             u'preobrat_v_mišljenju'
-            ]
-        self.assertEqual(S('about-face.n.02').lemma_names(lang='slv'), expected)
+            ])
+        self.assertEqual(sorted(S('about-face.n.02').lemma_names(lang='slv')), expected)
 
     def test_iterable_type_for_all_lemma_names(self):
         # Duck-test for iterables.
