@@ -15,11 +15,9 @@ which was also ported into Python in
 https://github.com/lium-lst/nmtpy/blob/master/nmtpy/metrics/mtevalbleu.py#L162
 """
 
-from __future__ import unicode_literals
 
 import io
 import re
-from six import text_type
 
 from nltk.corpus import perluniprops
 from nltk.tokenize.api import TokenizerI
@@ -32,7 +30,6 @@ class NISTTokenizer(TokenizerI):
     paragraph-based tokenization from mteval-14.pl; The sentence-based
     tokenization is consistent with the other tokenizers available in NLTK.
 
-    >>> from six import text_type
     >>> from nltk.tokenize.nist import NISTTokenizer
     >>> nist = NISTTokenizer()
     >>> s = "Good muffins cost $3.88 in New York."
@@ -74,17 +71,17 @@ class NISTTokenizer(TokenizerI):
     """
 
     # Strip "skipped" tags
-    STRIP_SKIP = re.compile('<skipped>'), ''
+    STRIP_SKIP = re.compile("<skipped>"), ""
     #  Strip end-of-line hyphenation and join lines
-    STRIP_EOL_HYPHEN = re.compile(u'\u2028'), ' '
+    STRIP_EOL_HYPHEN = re.compile("\u2028"), " "
     # Tokenize punctuation.
-    PUNCT = re.compile('([\{-\~\[-\` -\&\(-\+\:-\@\/])'), ' \\1 '
+    PUNCT = re.compile("([\{-\~\[-\` -\&\(-\+\:-\@\/])"), " \\1 "
     # Tokenize period and comma unless preceded by a digit.
-    PERIOD_COMMA_PRECEED = re.compile('([^0-9])([\.,])'), '\\1 \\2 '
+    PERIOD_COMMA_PRECEED = re.compile("([^0-9])([\.,])"), "\\1 \\2 "
     # Tokenize period and comma unless followed by a digit.
-    PERIOD_COMMA_FOLLOW = re.compile('([\.,])([^0-9])'), ' \\1 \\2'
+    PERIOD_COMMA_FOLLOW = re.compile("([\.,])([^0-9])"), " \\1 \\2"
     # Tokenize dash when preceded by a digit
-    DASH_PRECEED_DIGIT = re.compile('([0-9])(-)'), '\\1 \\2 '
+    DASH_PRECEED_DIGIT = re.compile("([0-9])(-)"), "\\1 \\2 "
 
     LANG_DEPENDENT_REGEXES = [
         PUNCT,
@@ -94,37 +91,37 @@ class NISTTokenizer(TokenizerI):
     ]
 
     # Perluniprops characters used in NIST tokenizer.
-    pup_number = text_type(''.join(set(perluniprops.chars('Number'))))  # i.e. \p{N}
-    pup_punct = text_type(''.join(set(perluniprops.chars('Punctuation'))))  # i.e. \p{P}
-    pup_symbol = text_type(''.join(set(perluniprops.chars('Symbol'))))  # i.e. \p{S}
+    pup_number = str("".join(set(perluniprops.chars("Number"))))  # i.e. \p{N}
+    pup_punct = str("".join(set(perluniprops.chars("Punctuation"))))  # i.e. \p{P}
+    pup_symbol = str("".join(set(perluniprops.chars("Symbol"))))  # i.e. \p{S}
 
     # Python regexes needs to escape some special symbols, see
     # see https://stackoverflow.com/q/45670950/610569
-    number_regex = re.sub(r'[]^\\-]', r'\\\g<0>', pup_number)
-    punct_regex = re.sub(r'[]^\\-]', r'\\\g<0>', pup_punct)
-    symbol_regex = re.sub(r'[]^\\-]', r'\\\g<0>', pup_symbol)
+    number_regex = re.sub(r"[]^\\-]", r"\\\g<0>", pup_number)
+    punct_regex = re.sub(r"[]^\\-]", r"\\\g<0>", pup_punct)
+    symbol_regex = re.sub(r"[]^\\-]", r"\\\g<0>", pup_symbol)
 
     # Note: In the original perl implementation, \p{Z} and \p{Zl} were used to
     #       (i) strip trailing and heading spaces  and
     #       (ii) de-deuplicate spaces.
     #       In Python, this would do: ' '.join(str.strip().split())
     # Thus, the next two lines were commented out.
-    # Line_Separator = text_type(''.join(perluniprops.chars('Line_Separator'))) # i.e. \p{Zl}
-    # Separator = text_type(''.join(perluniprops.chars('Separator'))) # i.e. \p{Z}
+    # Line_Separator = str(''.join(perluniprops.chars('Line_Separator'))) # i.e. \p{Zl}
+    # Separator = str(''.join(perluniprops.chars('Separator'))) # i.e. \p{Z}
 
     # Pads non-ascii strings with space.
-    NONASCII = re.compile('([\x00-\x7f]+)'), r' \1 '
+    NONASCII = re.compile("([\x00-\x7f]+)"), r" \1 "
     #  Tokenize any punctuation unless followed AND preceded by a digit.
     PUNCT_1 = (
-        re.compile(u"([{n}])([{p}])".format(n=number_regex, p=punct_regex)),
-        '\\1 \\2 ',
+        re.compile("([{n}])([{p}])".format(n=number_regex, p=punct_regex)),
+        "\\1 \\2 ",
     )
     PUNCT_2 = (
-        re.compile(u"([{p}])([{n}])".format(n=number_regex, p=punct_regex)),
-        ' \\1 \\2',
+        re.compile("([{p}])([{n}])".format(n=number_regex, p=punct_regex)),
+        " \\1 \\2",
     )
     # Tokenize symbols
-    SYMBOLS = re.compile(u"([{s}])".format(s=symbol_regex)), ' \\1 '
+    SYMBOLS = re.compile("([{s}])".format(s=symbol_regex)), " \\1 "
 
     INTERNATIONAL_REGEXES = [NONASCII, PUNCT_1, PUNCT_2, SYMBOLS]
 
@@ -141,28 +138,28 @@ class NISTTokenizer(TokenizerI):
         return text
 
     def tokenize(self, text, lowercase=False, western_lang=True, return_str=False):
-        text = text_type(text)
+        text = str(text)
         # Language independent regex.
         text = self.lang_independent_sub(text)
         # Language dependent regex.
         if western_lang:
             # Pad string with whitespace.
-            text = ' ' + text + ' '
+            text = " " + text + " "
             if lowercase:
                 text = text.lower()
             for regexp, substitution in self.LANG_DEPENDENT_REGEXES:
                 text = regexp.sub(substitution, text)
         # Remove contiguous whitespaces.
-        text = ' '.join(text.split())
+        text = " ".join(text.split())
         # Finally, strips heading and trailing spaces
         # and converts output string into unicode.
-        text = text_type(text.strip())
+        text = str(text.strip())
         return text if return_str else text.split()
 
     def international_tokenize(
         self, text, lowercase=False, split_non_ascii=True, return_str=False
     ):
-        text = text_type(text)
+        text = str(text)
         # Different from the 'normal' tokenize(), STRIP_EOL_HYPHEN is applied
         # first before unescaping.
         regexp, substitution = self.STRIP_SKIP
@@ -179,5 +176,5 @@ class NISTTokenizer(TokenizerI):
 
         # Make sure that there's only one space only between words.
         # Strip leading and trailing spaces.
-        text = ' '.join(text.strip().split())
+        text = " ".join(text.strip().split())
         return text if return_str else text.split()
